---
title: "PICOs: Persistent Compute Objects"
description: "Computational node for anything: person, place, organization, smart thing, dumb thing, concept, even a pothole."
excerpt: >
  every pico is serverless and cloud-native, presenting an API that can be fully customized by developers. Because they're persistent, picos support databaseless programming with intuitive data isolation. As an actor-model programming system, different picos can operate concurrently without the need for locks, making them a natural choice for easily building decentralized systems.
layout: single
permalink: /decentralized-web/biometrics/
canonical_url: "https://decentralized-id.com/decentralized-web/biometrics/"
categories: ["Decentralized Web"]
tags: ["PICO","IOT"]
last_modified_at: 2023-06-09
toc: true
toc_sticky: false
---

## Explainer

* [The Most Inventive Thing I've Done](https://www.windley.com/archives/2022/07/the_most_inventive_thing_ive_done.shtml) 2022-07 Phil Windley
  > every pico is serverless and cloud-native, presenting an API that can be fully customized by developers. Because they're persistent, picos support databaseless programming with intuitive data isolation. As an actor-model programming system, different picos can operate concurrently without the need for locks, making them a natural choice for easily building decentralized systems.
* [Introduction to Picos](https://iiw.idcommons.net/4C/_Introduction_to_Picos) 2021-05-06 Phil Windley
  > IoT, digital twins, device shadows, Conflict-free replicated data type (CRDT), CSP over DIDcomm
  > * [https://picolabs.io](https://picolabs.io) Pico Labs
  > * [https://github.com/Picolab/](https://github.com/Picolab/) repos
  > * [https://picolabs.atlassian.net/wiki](https://picolabs.atlassian.net/wiki) documentation
  > * [http://stackoverflow.com/questions/tagged/krl](http://stackoverflow.com/questions/tagged/krl) programming Q&A
* [Persistence, Programming, and Picos](https://www.windley.com/archives/2021/02/persistence_programming_and_picos.shtml) Phil Windley 2021-02
  > Picos show that image-based development can be done in a manner consistent with the best practices we use today without losing the important benefits it brings.
  > 
  > The project name, PICOS, is an abbreviation of “Privacy and Identity Management for Community Services”. The objective of the project is to advance the state of the art in technologies that provide privacy-enhanced identity and trust management features within complex community-supporting services that are built on Next Generation Networks and delivered by multiple communication service providers. The approach taken by the project is to research, develop, build trial and evaluate an open, privacy-respecting, trust-enabling identity management platform that supports the provision of community services by mobile communication service providers.
  > 
  > Learn more about the [motivation](http://www.picos-project.eu/Motivation.181.0.html), the [objectives](http://www.picos-project.eu/Objectives.182.0.html), [tasks](http://www.picos-project.eu/Tasks.183.0.html) and [achievements](http://www.picos-project.eu/Achievements.190.0.html) of PICOS, and get to know the PICOS exemplary [communities](http://www.picos-project.eu/Communities.184.0.html).

## Application
* [Picos at the Edge](https://www.windley.com/archives/2021/11/picos_at_the_edge.shtml) 2021-11 Phil Windley
  > You can play with this first hand at [NoFilter.org](https://nofilter.org/), which brands itself as a "the world's first unstoppable, uncensorable, undeplatformable, decentralized freedom of speech app." There's no server storing files, just a set of Javascript files that run in your browser. Identity is provided via [Metamask](https://metamask.io/) which uses an Ethereum address as your identifier. [I created some posts on NoFilter](https://nofilter.org/#/0xdbca72ed00c24d50661641bf42ad4be003a30b84) to explore how it works.
* [Ten Reasons to Use Picos for Your Next Decentralized Programming Project](https://www.windley.com/archives/2021/07/ten_reasons_to_use_picos_for_your_next_decentralized_programming_project.shtml) 2021-07
  > Summary: Picos are a programming model for building decentralized applications that provide significant benefits in the form of abstractions that reduce programmer effort. Here are ten eleven reasons you should use picos for your next decentralized application. Temperature Sensor Network Built from Picos I didn't start out to write a programming language that naturally supports
* [Credential-based login to a Pico-based application](https://iiw.idcommons.net/11P/_Credential-based_login_to_a_Pico-based_application) 2021-05-06 Bruce Conrad [slides](https://bruceatbyu.com/s/HRDDSiiw32)
  > The application that I wanted to demonstrate is what I call a fully-sharded database. BYU wants a community facing Human Resources domain data store, which means that other organizations on campus may wish to access HR data and so far they’ve been doing it by dipping directly into the production transactional database and that's not a good idea. And so, they have a team implementing a proof of concept using Postgres. And, I’m using picos to implement a fully-sharded alternative proof of concept. 
* [Building Decentralized Applications with Pico Networks](https://www.windley.com/archives/2021/02/building_decentralized_applications_with_pico_networks.shtml) 2021-02 Phil Windley
  >  Building a system of picos for a specific application requires programming them to perform the proper lifecycle management tasks to create the picos that model the application. Wrangler is a ruleset installed in every pico automatically that is the pico operating system. Wrangler provides rules and functions for performing these life-cycle management tasks. 

## Development
* [Announcing Pico Engine 1.0](https://www.windley.com/archives/2021/02/announcing_pico_engine_10.shtml) 2021-02 Phil Windley
  > Pico is short for “Persistent Compute Objects.”
  > Why Picos
  > - Persistent, personal, computational nodes → More individual autonomy
  > - Computational node for anything: person, place, organization, smart thing, dumb thing, concept, even a pothole
  > - Better, more scalable model for IoT → trillion node networks
  > - Picos support social things and trustworthy spaces
  > - Better sharing, more natural relationship-based interactions (borrow my truck, Fuse with two owners)
  > - Scales
  > - Substitutable hosting model → freedom of choice
  > - pico mesh
  > [...]
  > What are Picos?
  > - “Pico” is a neologism for persistent compute objects.
  > - Persistence is a core feature of how picos work.
  > - Picos exhibit persistence in three ways:
  > - Persistent identity—Picos exist, with a single identity, continuously from the moment of their creation until they are destroyed.
  > - Persistent state—Picos have state that programs running in the pico can see and alter.
  > - Persistent availability—Picos are always on and ready to process queries and events.
* [ACA-Pico working group](https://docs.google.com/document/d/12dWUFyL7u6OQkhnPObJOOlV-U2LDoHpF-ZQLj3hXbjA/edit)
* [Picolab/aries-cloudagent-pico](https://github.com/Picolab/aries-cloudagent-pico)
