---
title: Interoperability of Self Sovereign Identity Systems
description: Interoperability is a fundamental property of tech systems that are generative and respect individual privacy and autonomy.
excerpt: > 
  Interoperability moves from theory to reality when companies have meaningful ability to choose. It is predicated on open standards foundations that enable easy movement of data and vendors.
layout: single
toc: true
categories: ["Technology"]
tags: ["Aries","INTABA","Indicio","Transmute","Danube Tech","DHS","Open Badges","Interop"]
permalink: /development/interop/
canonical_url: "https://decentralized-id.com/development/interop/"
last_modified_at: 2023-07-02
---

## Main
* [Video] [SSI Report - Interoperability](https://www.youtube.com/watch?v=ezInITzb9p4)  2022-08-18 RootsID
  > Interoperability is the ultimate challenge of a Decentralized Self-Sovereign Identity. Hyperledger Aries is hosting an Interopathon to showcase all the work their community has done to promote Interoperability. We have also started discussions about a standard import/export format that would further improve interop across identity agents.
* [Digital Credentials and Self Sovereign Identity Workstream](https://inatba.org/reports/inatba-report-digital-credentials-and-self-sovereign-identity-workstream/) 2022-08 INTABA ([report](https://inatba.org/wp-content/uploads/2022/08/INATBA_Report_Digital_Credentials_and_Self-Sovereign_Identity_Workstream.pdf)
  > The objective of this workstream was to examine the technology and policy landscapes for digital credentials of INATBA-Governmental Advisory Body (GAB) members, identify the commonalities and gaps, and then develop recommendations for enabling interoperability and mutual support for digital credentials across borders.
* [Trust, Verifiable Credentials, and Interoperability](https://indicio.tech/trust-verifiable-credentials-and-interoperability/) 2022-03 Helen Garneau, Indicio
  > Accurate labeling, interoperability profiles, and testing are urgently needed to drive interoperability and scale decentralized identity, says a new [white paper](https://indicio.tech/wp-content/uploads/2022/03/Indicio_Report_TrustVerifiableCredentialsInteroperability_033022.pdf) from Indicio
  > Seven aspects of interoperability
  > 1. DID methods
  > 2. Content encryption key types
  > 3. Communication protocols
  > 4. Credential format and signature types
  > 5. Credential access / storage (wallet)
  > 6. Credential protocols and coordination formats
  > 7. Compatible governance / trust
* [Ugh! There's an App for That!](https://www.windley.com/archives/2021/10/ugh_theres_an_app_for_that.shtml) 2021-10 Phil Windley
  > Interoperability is a fundamental property of tech systems that are generative and respect individual privacy and autonomy. And, as a bonus, it makes people's live easier!
* [Interoperability is Not a Choice](https://medium.com/transmute-techtalk/interoperability-is-not-a-choice-387d57c6dc32) 2021-03-24 Transmute
  > [Interoperability](https://medium.com/transmute-techtalk/the-business-case-for-interoperability-a1a2b884297d) moves from theory to reality when companies have meaningful ability to choose. It is predicated on open standards foundations that enable easy movement of data and vendors.
  > 
  > Our team was proud to participate in the [US Department of Homeland Security Silicon Valley Innovation Program](https://www.dhs.gov/science-and-technology/svip) Interoperability Plug-fest this month. DHS SVIP has been leading the charge on interoperability for years now, putting their funding and networks on the table to lead the charge.
* [Different approaches to Interoperability](https://www.evernym.com/blog/getting-to-practical-interop-with-verifiable-credentials/) 2020-12-21 Daniel Hardman, Evernym
  > Several VC ecosystems have grown up around the VC spec. Each touts standards compliance and interoperability, yet they do not currently interoperate with one another. Let’s have a look at their differences and commonalities, and then explore a simple proposal that might make which language your VCs “speak” as transparent as which language you choose when you watch a movie.
* [Prioritizing Individual Sovereignty over Interoperability](http://web.archive.org/web/20230616014429/https://jolocom.io/blog/decentralized-identifiers-design-challenges/) 2019-04-26 Jolocom and Danube tech 
  > While we see the potential to enable interoperability with actors that do not put control in the hands of the subject of the digital identity, we must ensure that this interoperability on a technical level does not undermine the Design Goals that guided the creation of decentralized identifiers in the first place.

## Development
* [Open API for Interoperable Traceability](https://w3c-ccg.github.io/traceability-interop/openapi/#overview) 2023-06-21 CCG
  > `resolve:dids - Grants permission to resolve DIDsissue:credentials - Grants permission issue Verifiable Credentialsverify:credentials - Grants permission verify Verifiable Credentialsread:credentials - Grants permission to get Verifiable Credentialsupdate:credentials - Grants permission to update the status of Verifiable Credentialsprove:presentations - Grants permission to prove Verifiable Presentationsverify:presentations - Grants permission verify Verifiable Presentationssubmit:presentations - Grants permission to submit Verifiable Presentations`

## Interoperability Plug-fest
* [JFF & VC-EDU Plugfest #1: Leaping Towards Interoperable Verifiable Learning & Employment Records](https://kayaelle.medium.com/jff-vc-edu-plugfest-1-892b6f2c9dfb) 2022-07-07 Kayaelle
  > With this badge, they qualify to participate in Plugfest #2 which will focus on issuing and displaying LER VCs. Plugfest #2 will take place in November 2022 with plans to meet in person the day before the [Internet Identity Workshop](https://internetidentityworkshop.com/) on November 14 in Mountainview, CA. If vendors are interested in Plugfest #2 and didn’t participate in Plugfest #1, there is still an opportunity to do so by fulfilling the same requirements listed above including the video and earning a Plugfest #1 badge.
* [Interoperability Plugfest #1](https://w3c-ccg.github.io/vc-ed/plugfest-1-2022/) 2022 JFF & VC-EDU
  > - [Kick-off Meeting Deck](https://docs.google.com/presentation/d/1YoS3est-YnWO1tI7JjJDjSPSnIXJNon_TFosKyneaJg/edit?usp=sharing)
  > - [VC Implementation Guide](https://www.w3.org/TR/vc-imp-guide/)
  > - [Plugfest Open Badges v3 context](https://w3c-ccg.github.io/vc-ed/plugfest-1-2022/jff-vc-edu-plugfest-1-context.json)
  > - [Open Badges 3.0](https://imsglobal.github.io/openbadges-specification/ob_v3p0.html)
  > - [Universal Wallet](https://w3c-ccg.github.io/universal-wallet-interop-spec/)
  > - [DCC Learner Credential Wallet](https://github.com/digitalcredentials/learner-credential-wallet)
  > - [DCC Repository](https://github.com/digitalcredentials)
  > - [DCC Open Badges 3.0 Context NPM Module](https://github.com/digitalcredentials/open-badges-context)
  > - [DID Actor](https://api.did.actor/)
  > - [Hosted platform to resolve and manage DIDs](https://godiddy.com/)
  > - [DID DIF Universal Resolver](https://dev.uniresolver.io/)
* [DHS/SVIP Interoperability Plug-Fest 2 : Features Under Test ...](https://lists.w3.org/Archives/Public/public-credentials/2021Mar/0022.html) 2021-03-04 Anil John
*This presentation on the DHS/SVIP Interop Plug-Fest is epic!*
  > As you know, we had our first Interop plug-fest last year in May 2020, which was a heavy lift for our portfolio companies -- To be blunt, while there was a lot of hand-waving on interop, that was the first time anyone had demonstrated any manner of concrete cross-vendor / cross-platform interop in the VC/DID community.
* [DHS/SVIP Interoperability Plug-Fest 2 // VC/DID/Blockchain Multi-Platform & Multi-Vendor Interoperability Showcase](https://lists.w3.org/Archives/Public/public-credentials/2021Mar/0101.html)  2021-03-21 Anil John
  > ([slides](https://docs.google.com/presentation/d/1MeeP7vDXb9CpSBfjTybYbo8qJfrrbrXCSJa0DklNe2k/edit#slide=id.p1) Through the presentations and demos, we hope that you are able to gain an appreciation of the engineering depth, openness, inclusiveness and the multi-vendor, multi-platform interoperability that we demonstrated that is needed for these type of solutions to internet scale without locking anyone into a particular vendor or technology stack.
  > - [DHS SVIP Plugfest #2: Limited Disclosure Scenario](https://www.youtube.com/watch?v=BBSX0ljiCPU)
* [Video] [Transmute: Interoperability & Selective Disclosure in an Audit Authorization Scenario](https://www.youtube.com/watch?v=PodtjhO3vJo) 2021-03-24 Demo
  > Proof of COVID Vaccination Credential
  > ![](https://i.imgur.com/HldCXiQ.png)
* [Video] [Transmute + DHS SVIP: Showing Interoperability in a Supply Chain Scenario](https://www.youtube.com/watch?v=fngwogLRUGk) 2021-03-24 Transmute
  > ![](https://i.imgur.com/hfvvA0b.png)
* [Video] [DHS SVIP PlugFest 2021 – Interop Testing Demo](https://www.youtube.com/watch?v=mXLy2Rof_iA) 2021-03-23 Mattr
  > As part of our deliverables for the U.S. Department of Homeland Security's Silicon Valley Innovation Program, we developed capabilities including a MATTR web wallet, CHAPI credential interactions, and direct interoperability with issuance and verification infrastructure built by other vendors. The results of this work are documented in our publicly available open-source test suite: [https://w3c-ccg.github.io/vc-http-api/test-suite/mattr/](https://w3c-ccg.github.io/vc-http-api/test-suite/mattr/)​
* [Video] [DHS SVIP PlugFest 2021 – USCIS Appointment Demo](https://www.youtube.com/watch?v=dgcKYam4MiQ) 2021-03-23 Mattr
  > We showcase our Mobile Wallet and OIDC Bridge Platform Extension in action, demonstrating how BBS+ signatures and selective disclosure can allow users to manage which data they are sharing with relying parties in a privacy-preserving way. This work leverages a newly created [Appointment vocabulary for JSON-LD](https://mattrglobal.github.io/appointment-vocab/)
* [Video] [DHS SVIP PlugFest 2021 – Paper & Digital Vaccination Credentials](https://www.youtube.com/watch?v=fEBNGj377Vc) 2021-03-23 Mattr
  > We showcase how both paper and digital credentials can be verified using the same infrastructure, allowing for easier relying-party integration. This work leverages CBOR-LD and a newly created [Vaccination Certificate vocabulary](https://w3c-ccg.github.io/vaccination-vocab/)
* [Video] [Three-Vendor Interop - DHS SVIP Showcase Day](https://www.youtube.com/watch?v=dreJIx0_esE) 2023-03-18 Danube Tech
  > This is one of Danube Tech's contributions to the DHS/SVIP Interoperability Plug-Fest 2 // VC/DID Multi-Platform & Multi-Vendor Interoperability Showcase
* [Video] [Full Walkthrough DHS SVIP Showcase](https://www.youtube.com/watch?v=87B_OyqWzVE) 2021-03-18 Danube Tech
* [Video] [Interoperability Fest – Oil & Gas](https://www.youtube.com/watch?v=Kx49PklrHIY) Mavenet
* [Video] [Digital Bazaar Interop 1B](https://www.youtube.com/watch?v=-sr-7E7q79E)
* [Video] [Digital Bazaar Interop 1A](https://www.youtube.com/watch?v=emu301gvMJE)
