---
title: "The Pan Canadian Trust Framework"
description: "This framework is the next major step after the 2016 publication of the Pan-Canadian Trust Framework Overview by the Digital Identification and Authentication Council of Canada (DIACC)"
excerpt: >
  "The Treasury Board Secretariat of Canada (TBS) and Shared Services Canada (SSC) are seeking a standardized method to issue and rapidly verify portable digital credentials across many different contexts, thereby reducing human judgement error, increasing efficiency and ensuring digital credential veracity using cryptography." 
permalink: /government/canada/pctf/
canonical_url: https://decentralized-id.com/government/canada/pctf/
tags: ["Policy","Trust Framework","Canada","Verifiable Credentials","DIACC","PCTF"]
categories: ["Government"]
header:
  image: /images/pan-canadian-trust-header.webp
  caption: "[PCTF Placemat](https://canada-ca.github.io/PCTF-CCP/docs/PCTF-Placemat.pdf)"
  teaser: /images/pctf-teaser.webp
last_modified_at: 2023-06-09
---

## The Framework
* [Pan-Canadian Trust Framework (“PCTF”)](https://diacc.ca/trust-framework/)
  * [Trust Registries](https://diacc.ca/trust-framework/pctf-trust-registries/) 2023-03-28 Draft Recommendation V1.0 - Defines criteria, requirements, and guidelines regarding Trust Registries.
    > Stakeholders have identified the need for a set of criteria, requirements, and guidelines regarding Trust Registries governance, operations, and registration and certification management.
  * [Digital Wallet](https://diacc.ca/pctf-digital-wallet/) 2023-04-25 Final Recommendation V1.0 - Defines criteria, requirements, and guidelines regarding digital wallets.
    > Stakeholders have identified the need for a set of criteria that will be used to create well-designed, privacy enhancing digital wallets.
  * [Assurance Maturity Model](https://diacc.ca/trust-framework/pctf-assurance-maturity-model/) 2021-06-28 Draft Recommendation V1.0 - Provides guidance regarding how to use PCTF conformance criteria in order to properly classify Levels of Assurance.
    > Stakeholders have identified the need for an Assurance Maturity Model to provide guidance regarding the use of PCTF conformance criteria in order to classify, compare, and align different Levels of Assurance schemes.
  * [Glossary](https://diacc.ca/trust-framework/pctf-glossary/) 2020-03-10 Final Recommendation V1.0 - A list of terms identified in the PCTF.
    > Stakeholders have identified the need for a common set of definitions to be used to communicate with regard to identity and access management.
  * [Infrastructure](https://diacc.ca/trust-framework/pctf-infrastructure/) 2023-04-25 Final Recommendation V1.2 - Defines criteria, requirements, and guidelines regarding the trustworthiness of IT infrastructure.
    > Stakeholders have identified the need for a set of criteria, requirements, and guidelines regarding the trustworthiness of IT infrastructure.
  * [Credentials](https://diacc.ca/trust-framework/pctf-credentials/) 2020-06-01 Final Recommendation V1.0 - Defines criteria related to the creation, issuance, and management of credentials existing in digital form.
    > Stakeholders  have identified the need for a set of criteria related to the creation, issuance, and management of credentials existing in digital form.
  * [Verified Organization](https://diacc.ca/trust-framework/pctf-verified-organization/) 2020-02-17 Final Recommendation V1.0 - Defines criteria that allow organizations to exchange trustworthy information about themselves or others (individuals or organizations) with external parties.
    > Stakeholders have identified the need for a set of criteria that allow organizations to exchange trustworthy information about themselves or others (individuals or organizations) with external parties.
  * [Verified Person](https://diacc.ca/trust-framework/pctf-verified-person/) 2022-03-31 Final Recommendation V1.2 - Defines criteria used to establish that a natural person is real, unique and identifiable.
    > Stakeholders have identified the need for a set of criteria that will be used to establish that a natural person is real, unique and identifiable.
  * [Privacy](https://diacc.ca/trust-framework/pctf-privacy/) 2022-03-31 Final Recommendation V1.2 - Defines criteria concerned with the handling of personal data for digital identity purposes.
    > Stakeholders have identified the need for a set of criteria concerned with the handling of personal data for digital identity purposes.
  * [Authentication](https://diacc.ca/trust-framework/pctf-authentication/) 2019-05-15 Final Recommendation V1.0 - Defines criteria used to enable access to digital systems.
    > Stakeholders have identified the need for a set of criteria that will be used to enable access to digital systems.
  * [Notice Comment](https://diacc.ca/trust-framework/pctf-notice-consent/) 2019-04-03 Final Recommendation V1.0 - Defines criteria used to formulate a statement about the collection, use and disclosure of personal information, and to obtain a consent decision on that statement from a person authorized to do so.
    > Stakeholders have identified the need for a set of criteria used to formulate a statement about the collection, use and disclosure of personal information, and to obtain a consent decision on that statement from a person authorized to do so.
  * [Model](https://diacc.ca/trust-framework/pctf-model/) 2019-02-13 Final Recommendation V1.0 - A high-level model of PCTF related contextual information, goals, and objectives.
    > Stakeholders have identified the need for a high-level model to organize the Canadian Digital Identity Ecosystem.
  * [Overview](https://diacc.ca/trust-framework/pctf-overview/) 2016-08-01 Final - Sets out the vision and value proposition for the PCTF.
    > Canadian citizens and consumers, i.e. end users, are the beneficiaries of trust that will be achieved through service standardization and accountability to the PCTF.

## Background

* [The Public Sector Profile of the Pan-Canadian Trust Framework Working Group Close-Out Report](https://trbouma.medium.com/public-sector-profile-of-the-pan-canadian-trust-framework-version-1-2-and-next-steps-86ae7a96d6c7) 2020-12-12 Tim Bouma
  > the PSP PCTF WG was an important vehicle for ensuring public sector communication and discussion across Canada
* [Trust Frameworks? Standards Matter](https://medium.com/@trbouma/trust-frameworks-standards-matter-47c946992f44) 2020-11-15 Tim Bouma
  > He points at the NIST documents about it [Developing Trust Frameworks to Support Identity Federations](https://nvlpubs.nist.gov/nistpubs/ir/2018/NIST.IR.8149.pdf) published in 2018. He also points at the Canadian government’s definition of standards.
  > 
  > “a document that provides a set of agreed-upon rules, guidelines or characteristics for activities or their results. Standards establish accepted practices, technical requirements, and terminologies for diverse fields.”  He goes on to highlight a lot of the work being done in Canada and where it all sits relative to being a standard - “In closing, there are lots of trust frameworks being developed today. But to be truly trusted, a trust framework needs to either apply existing standards or become a standard itself.”
* [Progressing the pan canadian trust framework pctf](https://diacc.ca/2020/09/12/progressing-the-pan-canadian-trust-framework-pctf/) 2020-09 [Infographic](https://diacc.ca/wp-content/uploads/2020/04/PCTF-progress-infographic_September-2020.pdf)
  > Since 2016, the Digital ID & Authentication Council of Canada’s (DIACC) Trust Framework Expert Committee (TFEC) has been developing the Pan-Canadian Trust FrameworkTM (PCTF). It is one framework with many partners, and we thank all of those involved for their contribution in this momentous achievement.  
* [IMSC Pan-Canadian Trust Framework Executive Summary](https://medium.com/@trbouma/imsc-pan-canadian-trust-framework-executive-summary-5c89a72e06b5) 2020-04-01
  > This [document](https://drive.google.com/open?id=1Xmjh8QJZKWmRkaTtE2f43ISntD7jE6D5) describes Version 1.0 of the IMSC Pan-Canadian Trust Framework (PCTF). This framework is the next major step after the 2016 publication of the Pan-Canadian Trust Framework Overview by the Digital Identification and Authentication Council of Canada (DIACC), in collaboration with the Canadian public sector Identity Management Sub-Committee (IMSC) of the Joint Councils (JC).
* [Looking Ahead in 2020](https://medium.com/@trbouma/looking-ahead-in-2020-830afa372878) 2020-01-03
  > I believe it will be a breakout year for digital identity, and for the underlying technical infrastructure that we need to achieve our goals. I see the work progressing on two fronts: 1) Pan-Canadian Trust Framework, and, 2) Verifiable Credentials/Decentralized Identifiers Deployment.
* [Public Sector Profile of the Pan-Canadian Trust Framework Version 1.0 Recommendation Draft](https://medium.com/@trbouma/public-sector-profile-of-the-pan-canadian-trust-framework-version-1-0-4baf8ff0cfa0) 2019-07-05 [GitHub](https://canada-ca.github.io/PCTF-CCP/)
  > The public sector profile of the PCTF reflects:
  > - Evolution of the Identity Management Sub-Committee (IMSC) efforts. 
  > - The Need to Apply the PCTF for Assessments. 
  > - Policy Alignment.
* [White Paper: Canada’s Digital ID Future - A Federated Approach](https://www.cba.ca/embracing-digital-id-in-canada) 2019-05-30
  > In this brief, we highlight why Canada needs a digital identity system, how other countries have made progress in this area and the lessons we can learn from those experiences to build a system in Canada.
* [IMSC Pan-Canadian Trust Framework](https://medium.com/@trbouma/imsc-pan-canadian-trust-framework-1f68134e338a) 2019-03-25
  > A summary of the latest iterations before our final version to be delivered on March 31st, 2019. The near to final document is [here](https://drive.google.com/open?id=1P8kFJZfUV7PX25KEkZKk0XftrqqQp9FI)
* [A Quick Video Tour of the PCTF Trusted Processes and Cross-Referencing](https://medium.com/@trbouma/a-quick-video-tour-of-the-pctf-trusted-processes-and-cross-referencing-3c892a012edd) 2019-02-10
* [The Pan-Canadian Trust Framework Using Prolog](https://medium.com/@trbouma/the-pan-canadian-trust-framework-using-prolog-e62ffa911ff5) 2019-01-03
  > A ‘declarative framework’ (such as [Prolog](https://www.geeksforgeeks.org/prolog-an-introduction/)) focuses on the ‘what’ needs to be done, satisfied, relied on (i.e., proven to be true) versus ‘how to do it.’ In our case, with the Pan-Canadian Trust Framework (PCTF), it’s the question of ‘Can we rely on or accept a digital identity originating from a province or territory?’
* [ssimeetup- Overview of Proposed Pan Canadian Trust Framework](https://ssimeetup.org/overview-proposed-pan-canadian-trust-framework-ssi-tim-bouma-webinar-19/) 2019-01 [Slideshare](https://www.slideshare.net/SSIMeetup/overview-of-the-proposed-pancanadian-trust-framework-for-ssi-tim-bouma) 
  > The Government of British Columbia and the Government of Ontario have already rolled out a production system using the Sovrin Network for business registration and licensing; together they've issued over 6 million credentials, according to Windley. - [How Blockchain may Kill the Password](https://www.computerworld.com/article/3329962/blockchain/how-blockchain-may-kill-the-password.amp.html)
* [Pan-Canadian Trust Framework - Tim Bouma](https://medium.com/@trbouma/pan-canadian-trust-framework-eb65eac6c683) 2018-04-12
  > The Pan-Canadian Trust Framework is how we will formalize the approval and acceptance of a “trusted digital identity.”

{% include figure image_path="/images/canadian-digital-identity-history.png" alt="canadian-digital-identity-history" caption="[Annex E - 2014- 2017 Federating Identity: Milestones and Initiatives](https://docs.google.com/presentation/d/189DxjNv7EE7KtjkidB6EpwuvO2lIy7kEL-3DWtMAiQg/edit)" %}


* [PCTF overview](https://diacc.ca/2016/08/11/pctf-overview/) 2016-08
  > Toronto, August 11, 2016 – Today the Digital ID & Authentication Council of Canada (DIACC) releases the Pan-Canadian Trust Framework (PCTF) Overview, (English/French) a collaborative approach to developing a Pan-Canadian Trust Framework. The PCTF enableS Canada’s full and secure participation in the global digital economy through economic sector innovation and the enablement of modernized digital service delivery. The PCTF supports open government principles.
