---
date: 2020-11-17
title: "BCGov - Government of British Columbia Canada"
description: "BCGov's Verifiable Organizations Network (VON) is a community effort to establish a better way to find, issue, store and share trustworthy data about organizations."
excerpt: >
  "Digital technologies are transforming the way British Columbians live, work and play. To meet their changing expectations, government’s transformation is also underway. It’s about using modern tools and technologies to deliver the services people want and maximizing the power of data to improve the services people need." 
permalink: /government/canada/bcgov/
redirect_from: /public-sector/canada/
categories: ["Government"]
tags: ["Policy","Trust Framework","Canada","Verifiable Organizations Network","Trinsic","IIW","Aries","W3C","Trust over IP","Indy", "Real World","Orgbook"]
header:
  image: /images/bcgov-header.webp
  teaser: /images/bcgov-teaser.webp
last_modified_at: 2023-06-09
---

## Main
* [gov.bc.ca](https://www2.gov.bc.ca/gov/content/home) - The official website of the Government of British Columbia.
  > The Government of B.C. is made up of ministries, agencies and Crown corporations. Browse ministry, agency and Crown corporation websites for the latest news, service plans, publications and more.
* [British Columbia - Digital Government - B.C.’s digital future](https://digital.gov.bc.ca/)
  > Digital technologies are transforming the way British Columbians live, work and play. To meet their changing expectations, government’s transformation is also underway. It’s about using modern tools and technologies to deliver the services people want and maximizing the power of data to improve the services people need.
* [OrgBook BC](https://www.orgbook.gov.bc.ca/search) 
  > OrgBook BC provides verified data about organizations including:
  > - Business numbers
  > - Legal names and DBA names
  > - BC registration status
  > - Select licenses and permits
  > - Some addresses
* [British Columbia OrgBook – ‘Tell Us Once’ via Blockchain and Self-Sovereign Identity](https://digitalcanada.io/bc-orgbook-tell-us-once/) 2019-06-11
  > Canada is beginning to develop their own version of a “[Tell Us Once](https://digitalcanada.io/tell-us-once-legislation/)” Digital Identity policy, an approach pioneered in Europe by the likes of Estonia.
  > 
  > This is a policy where having provided your data to one government agency, you’ll never be asked for it again from another, defined explicitly through legislation.
* [BC Digital Trust](https://digital.gov.bc.ca/digital-trust/) BCGov
  > Our team offers services and tools to help people and businesses safely, securely and confidently identify themselves and communicate online, with government and beyond. 
* [BC Wallet](https://www2.gov.bc.ca/gov/content/governments/government-id/bc-wallet)
  > The focus of BC Wallet is to keep your information secure and confidential. Digital credentials in BC Wallet are highly tamper resistant and are only stored on your smartphone. The government is not told when, where or how you use BC Wallet. And BC Wallet only sends or receives information over secure, confidential connections. 
* [BC Wallet Technology Overview](https://digital.gov.bc.ca/digital-trust/about/about-bc-wallet/)
  > BC Wallet allows a person to receive, store (hold), and use (present) Digital Credentials in the Verifiable Credentials (VC) format. It is positioned at level 3 of the Trust Over IP Stack. 

## Partnership
* [OpenEarth partners with BCGov to develop a digital trust marketplace for climate accounting](https://www.openearth.org/blog/openearth-partners-with-the-government-of-british-columbia-to-develop-a-digital-trust-marketplace-for-climate-accounting) 2022-09-16 OpenEarth Foundation
  > OpenEarth Foundation partnered with the Mines Digital Trust initiative to allow BC companies to also share their greenhouse gas (GHG) emissions credentials to the [OpenClimate](https://www.openearth.org/projects/openclimate) platform so that they can be integrated into BC’s subnational climate inventory and showcased to interested purchasers and civic society

## Development

* [DevHub](https://developer.gov.bc.ca/)
  > One place that brings together resources to help build digital products for the BC Government
* [Shared Resources](https://bcgov.github.io/common-components-wiki/)
  > The Common Components team is working on ways to reduce the time and cost of delivering digital products and services. We plan to achieve this by making it easy to find, onboard to and use components like code and microservices that solve common problems across government. Our work is a priority action in BC’s Digital Framework.
* [Aries Verifiable Credential Registry](https://github.com/bcgov/aries-vcr)
  > Aries Verifiable Credentials Registry (VCR), part of the Hyperledger Aries family of Digital Trust technologies, provides a searchable public directory based on Verifiable Credentials (VCs). It was historically known as both OrgBook (which is actually a deployment of Aries VCR) and Indy Catalyst.
  > 
  > Aries VCR is actively developed by the British Columbia Government’s Digital Trust Team in Canada, and the most well-known live example is OrgBook BC.

## Code
* [bcgov/orgbook-api](https://bcgov.github.io/orgbook-bc-api-docs/) 2021-01-08
  > Various developer tools and documentation for using the OrgBook BC API as part of the Verifiable Organizations Network.
* [bcgov/von](https://github.com/bcgov/von) [Archived] - Verifiable Organizations Network
* [bcgov/aries-vcr](https://github.com/bcgov/aries-vcr)
  > Hyperledger Indy Catalyst is a set of application level software components designed to accelerate the adoption of trustworthy entity to entity1 communications based on Decentralized Identity / Self-Sovereign Identity technology and architecture. Indy Catalyst is builds upon globally available open standards and open source software. At present, Indy Catalyst builds upon Hyperledger Indy, common enterprise open source software, frameworks and patterns such as PostgreSQL, Python, Angular and RESTful APIs. Efforts will be taken to design the software to facilitate the incorporation of evolving open standards and technology. The impetus for Indy Catalyst came from the Verifiable Organizations Network (VON) project. More information about VON can be found at vonx.io
* [bcgov/orgbook-configurations](https://github.com/bcgov/orgbook-configurations) -  Build and Deployment Configurations for the Indy-Catalyst version of the OrgBook 
  > This repository contains the openshift-developer-tools compatible OpenShift configurations for the indy-catalyst instance of the OrgBook.
* [bcgov/von-bc-registries-agent-configurations](https://github.com/bcgov/von-bc-registries-agent-configurations) 2023-04-20  Build and Deployment Configurations for the Indy-Catalyst version of the BC Registries Agent 
  > This repository contains the openshift-developer-tools compatible OpenShift configurations for the indy-catalyst compatible instance of the von-bc-registries-agent.
* [bcgov/von-network](https://github.com/bcgov/von-network) 2023-06-01
  > A portable development level Indy Node network, including a Ledger Browser. The Ledger Browser (for example the BC Gov's Ledger for the GreenLight Demo Application) allows a user to see the status of the nodes of a network and browse/search/filter the Ledger Transactions.
* [bcgov/mobile-signing-service](https://github.com/bcgov/mobile-signing-service/) 2023-03-24
  > This is the Agent component to the BCDevX Mobile App Signing Service. The Signing Service is designed to be a self-serve system that enables development teams to sign and deploy build artifacts in a secure environment.
* [bcgov/a2a-trust-over-ip-configurations](https://github.com/bcgov/a2a-trust-over-ip-configurations) - OpenShift build and deployment configurations for the Access to Audio Trust Over IP components. 
  > This repository contains the openshift-developer-tools compatible OpenShift configurations to customize the builds and deployments of vc-authn-oidc for use with the A2A Trust Over IP project.
* [bcgov/aries-cloudagent-container](https://github.com/bcgov/aries-cloudagent-container) -  Runnable Docker image for the Hyperledger Aries Cloudagent 
* [bcgov/von-bc-registries-agent](https://github.com/bcgov/von-bc-registries-agent)
  > Components for plugging the BC Registries into the verifiable organizations network.
* [bcgov/von-bc-registries-audit](https://github.com/bcgov/von-bc-registries-audit) - Audit scripts for aries vcr/orgbook and bc registries issuer 

### Public Services and Procurement Canada: buyandsell.gc.ca : Achatsetventes.gc.ca

* [PSPC-SPAC-buyandsell/von_tails](https://github.com/PSPC-SPAC-buyandsell/von_tails) - Tails file server for von_anchor issuer and holder-prover anchors
* [PSPC-SPAC-buyandsell/von_base](https://github.com/PSPC-SPAC-buyandsell/von_base)
* [PSPC-SPAC-buyandsell/von_anchor](https://github.com/PSPC-SPAC-buyandsell/von_anchor) - VON anchor classes for interaction with sovrin/indy ledger via indy-sdk
* [PSPC-SPAC-buyandsell/von-image](https://github.com/PSPC-SPAC-buyandsell/von-image) - Standard docker images for building VON components
* [PSPC-SPAC-buyandsell/didauth](https://github.com/PSPC-SPAC-buyandsell/didauth) - DID authentication by way of HTTP Signatures for Hyperledger Indy agents
* [PSPC-SPAC-buyandsell/von_agent](https://github.com/PSPC-SPAC-buyandsell/von_agent) - VON agents using indy-sdk
* [PSPC-SPAC-buyandsell/von_connector](https://github.com/PSPC-SPAC-buyandsell/von_connector) - service wrapper API per agent, via django application
* [PSPC-SPAC-buyandsell/ReferenceVonActuator](https://github.com/PSPC-SPAC-buyandsell/ReferenceVonActuator) - Java implementation of actuator of reference von_connector implementation
* [PSPC-SPAC-buyandsell/demo-agent](https://github.com/PSPC-SPAC-buyandsell/demo-agent) - agent and api wrapper code base

## Background
* [John Jordan AMA - ToIP, BC Gov, Spinal Cord Injuries](https://iiw.idcommons.net/13C/_John_Jordan_AMA_-_ToIP,_BC_Gov,_Spinal_Cord_Injuries) by John Jordan
  > John shared about his journey and ongoing rehab,  and then moved on to what’s up with BCGov these days and looking ahead with the same.
* [Video Presentation] [VON, OrgBook BC and our vision](https://bc-von.s3.amazonaws.com/2018-06-VON-Webinar-for-Sovrin-Indy-Community.mp4) John Jordan (BC Gov)
  > How the Orgbook enables the Digital Economy
* [Verifiable Organizations Network]({{ site.baseurl }}/government/canada/bcgov/von/hgf-2018-production-government-deployment-hyperledger-indy/) - A Production Government Deployment of Hyperledger Indy Presentation by John Jordan and Stephen Curran at HGF 2018 (Transcript)
  > VON's founding members are governments who are, by law, trusted issuers of data about organizations. The Province of British Columbia, Province of Ontario and the Government of Canada have come together to create the initial services needed to establish VON.
  >
  > VON's founders have delivered new Indy-based open source components which form VON's backbone. TheOrgBook is a publicly accessible repository of verifiable claims about organizations. VON-X enables services to verify and issue credentials. 

### IIW Book

<blockquote class="twitter-tweet"><p lang="en" dir="ltr">So far the killer demo of <a href="https://twitter.com/hashtag/IIW?src=hash&amp;ref_src=twsrc%5Etfw">#IIW</a> 28 is “IIWBook” from <a href="https://twitter.com/jljordan42?ref_src=twsrc%5Etfw">@jljordan42</a> &amp; BC Gov &amp; Streetcred teams. First you get a <a href="https://twitter.com/hashtag/verifiablecredential?src=hash&amp;ref_src=twsrc%5Etfw">#verifiablecredential</a> of your verified email address and IIW attendance, then you can create peer-to-peer DID-to-DID connections with any other IIWBook user. Mind blown! <a href="https://t.co/2exkD3xdXP">pic.twitter.com/2exkD3xdXP</a></p>&mdash; Drummond Reed (@drummondreed) <a href="https://twitter.com/drummondreed/status/1123647138200600576?ref_src=twsrc%5Etfw">May 1, 2019</a></blockquote> <script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script> 

* [IIW Book](https://github.com/bcgov/iiwbook)
* [Highlights of Internet Identity Workshop (IIW) #28](https://docs.google.com/presentation/d/1jG4HxFhzQoKBp7xqD_8A3L1DtJQ-zKFbJn-IVQ9lMvk/htmlpresent)
  > The BC Gov team led a killer agent interop demo
  > 
  > - https://iiw.vonx.io/ to start the demo
  > - You can use any of 3 different agent/wallet apps
  > - First you get a verifiable credential of your email address
  > - Then you get a VC that you were an IIW attendee
  > - Then you were added to the IIWBook directory
  > - Then you could create your own private peer-to-peer connection with any other IIWBook member
* [IIW Book! Come get a REAL IIW attendance verification credential and prove it to your IIW friends using your phone!](https://iiw.idcommons.net/IIW_Book!_Come_get_a_REAL_IIW_attendance_verification_credential_and_prove_it_to_your_IIW_friends_using_your_phone!)
  >  Key understanding: a demonstration of an identity authentication, issuing, relying party connection and document/chat exchange using authenticated identities. 
* [BC Gov , MATTR, STREETCRED – IIW Book Redux](https://iiw.idcommons.net/BC_Gov_,_MATTR,_STREETCRED_%E2%80%93_IIW_Book_Redux)
  > There was continued discussion about a Connectathon last February where 6 different systems were verified as connecting. Evernym was not a system that passed, but this was not held as a lack of ability as much as direction of activities – they had more important features they were working on. 

Link to presentation provided by John Jordon on Tuesday (Part 1) & Wednesday (Redux): [http://IIW.vonx.io](http://IIW.vonx.io)

* [The VON IIW 28 Demonstration: IIWBook](https://vonx.io/how_to/iiwbook)
  > In late March 2019, the VON team created AgentBook to demonstrate the interoperability of independently created agents. These agents were able to successfully establish DID-based communication channels. Now, with IIWBook, we’ve added a (literal) new layer by extending the core of AgentBook with the ability to exchange verifiable credentials. Even more exciting, through collaboration with Streetcred.id and Spark New Zealand, we have a mobile agent (or two!).

{% include video id="bZrWAsD42-I" provider="youtube" %}
