---
title: European Digital Identity and SSI
layout: single
description: A digital identity available to all Europeans, enabling access to digital services across the EU and control over which information is shared with third parties
excerpt: By using the European Digital Identity, the user only has to select the necessary documents that are stored locally on his digital wallet to reply to the bank’s request. Then, verifiable digital documents are created and sent securely for verification to the bank, who can then continue with the application process.
permalink: /government/europe/
canonical_url: 'https://decentralized-id.com/government/europe/'
categories: ["Government"]
tags: ["Policy","Ethereum","uPort","Europe","EU","Zug","Finland","Spain","Netherlands","Germany","Catalonia","ESSIFlab","eIDAS","EBSI","Verifiable Credentials","W3C","IDUnion","Aries","Indy"]
header:
  image: /images/european_union-header.webp
  caption: "[image source](https://www.fidh.org/en/international-advocacy/european-union/eu-budget-joint-call-by-civil-society-to-reverse-cuts-to-the-ndici)"
  teaser: /images/europe_teaser.webp
last_modified_at: 2023-06-15
---

## General 
* [@EIC2022 Centralized & Decentralized Identity converging](https://www.linkedin.com/pulse/eic2022-centralized-decentralized-identity-converging-kuppinger/) 2022-05-18 Martin Kuppinger
  > For me, the most relevant new topic and trend was to finally see the convergence of decentralized identities (DID) and traditional approaches on IAM starting. DID, also referred to as SSI (Self Sovereign Identity) or verifiable credentials, is a concept where the user has a wallet that holds proofs of identities and attributes.
* [State of SSI in Europe and Necessity for Network-of-Networks (convened by Sovrin)](https://iiw.idcommons.net/11F/_State_of_SSI_in_Europe_and_Necessity_for_Network-of-Networks_(convened_by_Sovrin)) 2021-05-06 Andre Kudra
  > 3. Hyperledger Indy and Aries technology stack
  > 4. ‘Network of networks’ which has been a key concept at the Sovrin Foundation
  > 5. The topic is meant to be a conversation as an outline based on material information which can be shared publicly
  > 6. EBSI is one of the funded projects from the EU
  > 7. ESSIF is one of the projects in this portfolio - have issued a request for proposal for consulting (not in the network of networks topic but other areas)
  > 8. Findy (Finland) - yet to go live. Has public and private partners.
  > 9. Projects underway at [Spain](https://alastria.io/en/id-alastria/) and other member nations in EU
  > 10. Substantial funding behind Indy based technology stack deployments are being seen
  > 11. Germany has 3 major streams active in the identity space
* [literature] [Legal Identity, Development and Democracy in Northern Europe](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=4110873) 2022-06-01 Jaap van der Straaten :: SSRN
  > In circles of identity management scholars and practitioners, the general consensus is that the region of northern Europe provides a good practice example [...] Out of the eighteen countries included in northern Europe in this paper, one has no national ID; another denies it has, and seven countries only have a voluntary ID. The extent of national ID coverage is hardly known. Also in the European Union, only six in ten countries have a mandatory ID. It does not matter.


## EU

* [End-To-End Encryption is Too Important to Be Proprietary](https://doctorow.medium.com/end-to-end-encryption-is-too-important-to-be-proprietary-afdf5e97822) 2022-05-02 Cory Doctorow
  > The EU’s Digital Markets Act (DMA) is set to become law; it will require the biggest tech companies in the world (Apple, Google and Facebook, and maybe a few others) to open up their instant messaging services (iMessage, Facebook Messenger, Whatsapp, and maybe a few others) so that smaller messaging services can plug into them. These smaller services might be run by startups, nonprofits, co-ops, or even individual tinkerers.
* [The European Digital Identity Regulation](https://www.european-digital-identity-regulation.com/) 2023-04-08
  > The Regulation amends Regulation (EU) 910/2014 on electronic identification and trust services for electronic transactions in the internal market (‘the eIDAS Regulation’). This amendment is required, as digitalisation of all functions of society has increased dramatically. The provision of both public and private services is increasingly becoming digital after the COVID-19 pandemic. 
* [The European Declaration on Digital Rights puts people in the firing line of the digital transformation](https://blog.xot.nl/2022/03/06/the-european-declaration-on-digital-rights-puts-people-in-the-firing-line-of-the-digital-transformation/index.html) 2022-03-06 Jaap-Henk Hoepman
  > By focusing on the risk to individual citizens, the Declaration complete ignores the systemic risks introduced by the digital transformation (and in general the reliance on so called [programmable infrastructures](https://www.tudelft.nl/tbm/programmable-infrastructures), as expressed by Seda Gürses and Martha Poon among others).
* [Commission puts forward declaration on digital rights and principles for everyone in the EU](https://ec.europa.eu/commission/presscorner/detail/en/ip_22_452) 2022-01-26 EU Commission
  > The draft declaration covers key rights and principles for the digital transformation, such as placing people and their rights at its centre, supporting solidarity and inclusion, ensuring the freedom of choice online, fostering participation in the digital public space, increasing safety, security and empowerment of individuals, and promoting the sustainability of the digital future.
  > 
  > These rights and principles should accompany people in the EU in their everyday life: affordable and high-speed digital connectivity everywhere and for everybody, well-equipped classrooms and digitally skilled teachers, seamless access to public services, a safe digital environment for children, disconnecting after working hours, obtaining easy-to-understand information on the environmental impact of our digital products, controlling how their personal data are used and with whom they are shared.
* [Global state of SSI and how to build on it: EU report](https://www.biometricupdate.com/202201/global-state-of-ssi-and-how-to-build-on-it-eu-report) 2022-01-24
  > The European Union’s cybersecurity agency has been busy typing up its research. The latest report is an overview of Self-Sovereign Identity (SSI) technologies, standards, providers and regulation from around the world with a view to their relevance applicability to the EU project for digital identity for individuals and businesses.
  * [Digital Identity: Leveraging the SSI Concept to Build Trust](https://www.enisa.europa.eu/publications/digital-identity-leveraging-the-ssi-concept-to-build-trust)
    > It critically assesses the current literature and reports on the current technological landscape of SSI and existing eID solutions, as well as the standards, communities, and pilot projects that are presently developing in support of these solutions. This study takes a wide view of decentralised electronic identity, considers possible architectural elements and mechanisms of governance, and identifies security risks and opportunities presented by SSI in view of cross-border interoperability, mutual recognition, and technology neutrality as required by eIDAS.
* [Joining forces towards European digital credentials](https://onedrive.live.com/?authkey=%21ADoEGcIwiKDydcg&cid=F7FF746DED29F767&id=F7FF746DED29F767%2183805&parId=F7FF746DED29F767%2183804&o=OneUp) 2021-11-30 European Commission
  > The European BlockchainPartnership is a group of 29 countries and the EC. We help public administrations accelerate the creation of trustworthy cross border digital services.9Having this opportunity in mind, the EBSI (European BlockchainServices Infrastructure) has been developed. 
  > 
  > Our vision is to accelerate the creation of cross-border services and put blockchainat the service of public administrations for the purpose of verifying information, making the services trustworthy. 
  > 
  > EBSI is the first EU-wide blockchaininfrastructure, driven by the public sector, in full respect of European values and regulations. EBSI is supported by 29 countries (All EU Member States, Norway and Lichtenstein) and the EC forming the European BlockchainPartnership (EBP).
* [The “Secure Platform” Concept for Europe - a Trusted and Secure Foundation for a Human-Centric Digital World.](https://mydata.org/2021/06/04/guest-post-the-secure-platform-concept-for-europe/) 2021-06-04 MyData
  > The following article discusses the technical requirements needed to protect our personal data and to ensure a safer digital world. It presents solutions for creating an open and secure IT infrastructure where data privacy can always be guaranteed. The article has been written by esatus, founding member and lead of the “Secure Platform” working group, a thematic group within [the IT Security Association Germany (TeleTrusT)](https://www.teletrust.de/en/startseite/).
* [TechCrunch Europe wants to go its own way on digital identity](https://techcrunch.com/2021/06/03/europe-wants-to-go-its-own-way-on-digital-identity/) 2021-06-03
  > Alongside today’s regulatory proposal they’ve put out a recommendation, inviting member states to “establish a common toolbox by September 2022 and to start the necessary preparatory work immediately” — with a goal of publishing the agreed toolbox in October 2022 and starting pilot projects (based on the agreed technical framework) sometime thereafter.
  > 
  > “This toolbox should include the technical architecture, standards and guidelines for best practices,” the commission adds, eliding the large cans of worms being firmly cracked open.
 * [Digital Identity for all Europeans](https://commission.europa.eu/strategy-and-policy/priorities-2019-2024/europe-fit-digital-age/european-digital-identity_en) 2021-06
  > The European Digital Identity will be available to EU citizens, residents, and businesses who want to identify themselves or provide confirmation of certain personal information. It can be used for both online and offline public and private services across the EU.
  > 
  > Every EU citizen and resident in the Union will be able to use a personal digital wallet.
* [A trusted and secure European e-ID - Regulation](https://digital-strategy.ec.europa.eu/en/library/trusted-and-secure-european-e-id-regulation) 2021-05-28
  > By offering a European Digital Identity framework based on the revision of the current one, at least 80% of citizens should be able to use a digital ID solution to access key public services by 2030.
  > [...]
  > The legal instrument aims to provide, for cross-border use:
  > – access to highly secure and trustworthy electronic identity solutions,
  > – that public and private services can rely on trusted and secure digital identity solutions,
  > – that natural and legal persons are empowered to use digital identity solutions,
  > – that these solutions are linked to a variety of attributes and allow for the targeted sharing of identity data limited to the needs of the specific service requested,
  > – acceptance of qualified trust services in the EU and equal conditions for their provision.
* [Overview of Member States' eID strategies](https://ec.europa.eu/digital-building-blocks/wikis/download/attachments/364643428/eID_Strategies_v4.0.pdf) 2021-04-07
  > With this in mind, the following report provides an overview of the national approaches to electronic identification, describing how the 27 Member States are rolling out eID solutions to ensure that digital services can be securely accessed both at national and at European level. The report focusses on the approaches towards eID outlined in national strategy documents, together with other supporting documentation and web resources, with the aim of offering a thorough understanding of the eID state of play across Europe. This understanding of national strategies can feed into discussions on future EU-level action on eID.
* [The growth factors of self-sovereign identity solutions in Europe](https://www.researchgate.net/publication/349899411_The_growth_factors_of_self-sovereign_identity_solutions_in_Europe) 2020-10 Adrian Doerk
  > This thesis introduces the concept of self-sovereign identity and analysis the factors required to achieve adoption of the concept. It describes the basic components of a self-sovereign identity system and provides the reader with an overview of important conceptual theories to understand the differences to traditional identity systems and the unique approach taken instead. It then dives into the status quo of the discussions around business, technology, legal and governance aspects. It further examines the central factors for the user and describes a know your costumer use-case as well as the current efforts and challenges for higher education certificates for learners. Furthermore, it depicts the diffusion factors of the innovation. While the legal aspects are mainly concerned with regulations from the European Union, the findings in this thesis can be applied globally.

### See [EBSI]({% link _posts/government/europe/2023-06-08-ebsi.md %}), [eIDAS]({% link _posts/government/europe/2020-01-06-eIDAS.md %}), and [eSSIF-Lab]({% link _posts/history/2023-06-08-essif-lab.md%})

## Regional
### Findynet - Finland
* [Finnish tech co-op receives government grant to develop a self-sovereign identity network](https://www.thenews.coop/164789/topic/technology/finnish-tech-co-op-receives-government-grant-to-develop-a-self-sovereign-identity-network/) 2022-09-02 TheNews
  > The Finnish Government has awarded a €3m (£2.6m) grant to [Findynet Cooperative](https://findy.fi/en/) for a pilot project aiming to build a self-sovereign identity network.
* [The Findynet Cooperative receives government grant to develop a trusted way to share information in electronic interactions](https://findy.fi/en/findy-a-visionary-initiative-by-the-public-and-private-sectors-is-developing-a-new-type-of-verifiable-data-network-that-strengthens-finlands-position-as-a-driving-force-in-building-digital/) 2022-08-31 Findy.fi
  > The aim of this public-private cooperation is to strengthen Finland’s leading position in digitalization and support the emergence of investments in new digital services.
* [The Missing Network Layer Model](https://findy-network.github.io/blog/2022/03/05/the-missing-network-layer-model/) 2022-03-05 Findy *Epic Post*
  > You might think that I have lost my mind. We have just reported that our Indy SDK based DID agency is [AIP 1.0](https://github.com/hyperledger/aries-rfcs/blob/main/concepts/0302-aries-interop-profile/README.md) compatible, and everything is wonderful. What’s going on?

### Spain
* [Alastria](https://alastria.io/) 
  > a non-profit consortium building a national blockchain ecosystem for Spain. The security and veracity of information will be ensured through the identification of natural and legal persons, while at the same time allowing citizens to have control over their personal information in a transparent way following the guidelines set by the European Union.
* [alastria/alastria-identity](https://github.com/alastria/alastria-identity) 2023-02-03
  > At this moment, this solution has been developed and tested for Quorum (Geth) on the Alastria Red-T network. More information about its nodes and the network can be found in the alastria-node repository. In the future, the objetive is that this works with other Alastria networks such as Besu Red-B or Hyperledger Fabric Red-H.
* [Verifiable Credentials for Digital Identity Projects](https://knowledge.wealize.digital/en/blog/verifiable-credentials-for-digital-identity-projects) 2021-08-26
  > The Spanish Association for Standardization (UNE) has recently published the [UNE 71307-1](https://www.une.org/encuentra-tu-norma/busca-tu-norma/norma?c=N0064986) Digital Enabling Technologies Standard. This is the first global standard on decentralized identity management, based on Blockchain and Distributed Ledger Technologies (DLT).
* [Alastria Digital Identity: the Spanish Blockchain solution for SSI - Carlos Pastor](https://www.slideshare.net/SSIMeetup/alastria-digital-identity-the-spanish-blockchain-solution-for-ssi-carlos-pastor) 2018-06-28 SSI Meetup
  > Alastria ID proposes an implementation of the Self Sovereign Identity paradigm over a public-permissioned Blockchain and will be presented by Carlos Pastor, Alastria’s Digital Identity Commission Leader

<iframe src="//www.slideshare.net/slideshow/embed_code/key/Hh5gNODSCRgYr1" width="595" height="485" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="border:1px solid #CCC; border-width:1px; margin-bottom:5px; max-width: 100%;" allowfullscreen> </iframe> 

### Netherlands

![](https://i.imgur.com/CVA9t94.png)

* [Deployment of a Blockchain-Based Self-Sovereign Identity - Delft](https://arxiv.org/pdf/1806.01926.pdf) 2019-06-07
  > This solution for making identities Self-Sovereign, builds on a generic provable claim model for which attestations of truth from third parties need to be collected. The claim model is then shown to be both blockchain structure and proof method agnostic. Four different implementations in support of these two claim model properties are shown to offer sub-second performance for claim creation and claim verification. Through the properties of Self-Sovereign Identity, legally valid status and acceptable performance, our solution is considered to be fit for adoption by the general public
* [TrustChain] [TU Delft helps develop digital ID for use on your phone](https://www.tudelft.nl/en/2018/tu-delft/tu-delft-helps-develop-digital-id-for-use-on-your-phone/) 2018-06-07
  > As part of the Dutch Blockchain Coalition, Delft University of Technology (TU Delft, The Netherlands) has joined forces with the Netherlands Identity Data Agency (RvIG), a division of the Ministry of Foreign Affairs and Kingdom Relations (BZK), IDEMIA (the current manufacturer of Dutch passports) and law firm CMS, in developing an initial prototype
* [Slides] [TrustChain: A Sybil-resistant scalable blockchain](https://slideplayer.com/slide/16485523/) 2018-03-22
  > Source: Future Generation Computer Systems, Article in Press, Sep. 2017
  ![](https://i.imgur.com/xI2B1MF.png)
* [Dutch Blockchain Coalition](https://dutchblockchaincoalition.org)
  * [Action Agenda](https://dutchblockchaincoalition.org/assets/images/default/Dutch-Blockchain-Coalition-action-agenda-ENG.pdf) 2017-06-15
    > The coalition is permanently open for experts and stakeholders who want to make a contribution so that the coalition realises the maximum result. In this process, it will be continuously considered where the best match lies between the expertise offered and the interest of the programme, which should be viewed as a rolling agenda.
* [Accenture, APG, Brightlands, Chamber of Commerce, De Volksbank, Rabobank, TNO] [Self-Sovereign Identity Framework and Blockchain](https://ercim-news.ercim.eu/en110/special/self-sovereign-identity-framework-and-blockchain) 2017-06-29
  > The goal is to specify, validate and ultimately build a trustworthy, open digital infrastructure for self-sovereign identities that is secure, decentralized, open source, supports privacy (e.g., GDPR compliance) in multiple roles, and lacks a single point of failure or large information honey-pot. We aim to follow well-established requirements for user-centric identity systems 

### Germany

* [Fintech Humans and One37 Identity Enter Into Strategic Partnership in Germany](https://www.bloomberg.com/press-releases/2022-07-28/fintech-humans-and-one37-identity-enter-into-strategic-partnership-in-germany) 2022-07-28 Bloomberg
  > Through its membership in DIACC, One37 contributes to the future of digital identity by leveraging the lessons from its own real-life use-cases in Canada where Verifiable Credentials play an increasingly crucial role.
* [Video] [Reinventing Government with Technology - Sebastian Manhart](https://www.youtube.com/watch?v=1fTJA0r_XFg) 2021-12-01 KuppingerCole
  > Technical Advisor on Digital Identity for the German Chancellery to explore governmental reform and understand stakeholder expectations behind the rollout of digital identity projects in the post-COVID era.
* [IDnow AutoIdent will soon be usable according to German TKG](https://www.idnow.io/press/idnow-autoident-usable-german-tkg/) 2021-10-14 IDNow
  > Automated identification procedures ensure seamless processes without media disruption and increase cost efficiency. By modernizing laws that allow these procedures, many cases can be simplified and modernized in the future.
* [Digital identities: German-Finnish cooperation agreed](https://www.bundesregierung.de/breg-de/suche/digitale-identitaeten-deutsch-finnische-zusammenarbeit-vereinbart-1962298) 2021-09-22 Bundesregierung
  > The content of the joint declaration is close bilateral cooperation in the development of a cross-border ecosystem of digital identities based on the principles of Self-Sovereign Identity (SSI).

#### Secure Digital Identities
* [ID-Ideal as an integrated solution](http://web.archive.org/web/20230616101616/https://jolocom.io/blog/id-ideal-as-an-integrated-solution/) 2021-11-17 Jolocom
  > - Trust Framework: harmonize various ID services and create standards for secure digital identities
  > - High relevance to everyday life and very good usability to increase the incentive
  > - Establishing a TrustNest initiative: an open community that promotes certification, exchange, and further development
* [The latest in the DWeb: Jolocom’s breakthrough](http://web.archive.org/web/20230616055225/https://jolocom.io/blog/sdi-breakthrough/) 2021-05-06 Jolocom
  > At the last DWeb Meetup, we were invited to share our role in the German Government’s 60M Euro SDI (Secure Digital Identities) innovation project to bring “Self-Sovereign Identity” to German and EU citizens.
* [IDunion Introduction and AMA (there will be another one tomorrow!)](https://iiw.idcommons.net/12D/_IDunion_Introduction_and_AMA_(there_will_be_another_one_tomorrow!)) 2021-05-06 Andre Kudra, IDunion
  > IDunion is also a [project](https://www.digitale-technologien.de/DT/Redaktion/DE/Standardartikel/SchaufensterSichereDigIdentProjekte/Schaufensterprojekte/sdi-projekt_idunion.html) co-funded by the [German Federal Ministry of Economic Affairs (BMWi)](https://www.bmwi.de/Navigation/EN/Home/home.html) as part of the [Showcases Secure Digital Identities program](https://www.digitale-technologien.de/DT/Navigation/DE/ProgrammeProjekte/AktuelleTechnologieprogramme/Sichere_Digitale_Identitaeten/sichere_digitale_ident.html)
* [Showcase programme “Secure Digital Identities”](https://www.digitale-technologien.de/DT/Redaktion/EN/Standardartikel/sdi_programm.html) 2020-06 Digitale Technoligen DE
  > With this innovation competition, the Federal Ministry for Economic Affairs and Climate Action (BMWK) is directly contributing to Germany’s digital sovereignty and data security on the Internet. The measure aims to strengthen the confidence of citizens and companies in digital transformation.

### Catalonia

* [Catalan digital ID program using Blockchain wins government approval](https://www.secureidnews.com/news-item/catalan-digital-id-program-using-blockchain-wins-government-approval/) 2019-09-26
  > The regional government of Catalan [reportedly](https://tokenpost.com/Catalan-government-to-develop-DLT-based-self-sovereign-digital-ID-platform-3347) has “launched a new project to create decentralized and self-sovereign digital identity based on distributed ledger technology.”
* [Catalan government announces self-sovereign identity project](https://www.ledgerinsights.com/catalan-government-self-sovereign-identity/) 2019-09-09
  > The government of Catalonia announced its plans for self-sovereign identities (SSIs) for citizens based on blockchain technology. The project, named IdentiCAT, was revealed by the President of Catalonia Quim Torra and will allow citizens to be the “owner, manager and exclusive custod[ian] of his identity and data”.
* [Catalonia Announces Decentralized ID System the Govt Won’t Control](https://cointelegraph.com/news/catalonia-announces-a-decentralized-id-system-the-govt-wont-control) 2019-09-09
  > Citizens using IdentiCAT will reportedly be able to choose what data they are willing to share with the government, and request it to store a portion of it and share it with third parties.

## Interop
* [Validated ID is set to complete the S4EDI20 interoperability tests](https://www.validatedid.com/post-en/validated-id-is-set-to-complete-the-as4edi20-interoperability-tests) 2022-09-18 ValidatedID
  > The interoperability tests are being carried out with 2 PEPPOL APs of the entities SATAPROMOFARMA and Ionite, and include the use of our solution and all steps of the data exchange process. It covers the operation of ID Validated AP and SMP. 
* [Pilot] [Interoperable decentralised identity between Aigües de Barcelona, CaixaBank and Validated ID](https://www.validatedid.com/post-en/open-innovation-project-for-the-collaboration-between-large-companies-and-emerging-companies) 2022-08-09 Validated ID
  > The lines of action of the laboratory are framed in six blocks: resilient water resources, the impact of global change; efficient infrastructure management; the environment and health; water and energy; and water demand management. The projects developed contribute to the achievement of one or more Sustainable Development Goals, putting the citizen at the center of digital transformation and advocating a perspective on technological humanism.
* [Video] [Building interoperable self-sovereign identity for Europe](https://www.youtube.com/watch?v=iN6N_aIeHlU) TNO Oskar van Deventer
  > ways to build an SSI ecosystem and architecture together that is interoperable and technologically mature fit for society and funding opportunities for SSI projects through grants.
* [Adopting eID in Europe and Beyond](https://stateofidentity.libsyn.com/adopting-eid-in-europe-and-beyond) State of Identity
  > Digital identity is now recognized as a key building block in digitizing public administration; however, it requires interoperability with private sector use cases to drive value for its citizens.
* [Three Governments enabling digital identity interoperability](https://medium.com/in-present-tense/three-governments-enabling-digital-identity-interoperability-bbcfc60c3a80) Heather Vescent
  > On September 15, 2021, I moderated a panel with representatives from the United States Government, the Canadian Government, and the European Commission. Below is an edited excerpt from the panel

## Organization

* [European Union Digital Identity Wallet Consortium](https://eudiwalletconsortium.org/) EUDI Wallet Consortium
  > The EU Digital Wallet Consortium (EWC) is a joint effort to successfully leverage the benefits of the proposed EU digital identity in the form of Digital Travel Credentials across the Member States. The EWC intends to build on the Reference Wallet Application to enable a use case focused on Digital Travel Credentials.
* [Self-Sovereign Identity Working Group](https://europeanblockchainassociation.org/eba-working-group-self-sovereign-identity-eussi/) European Blockchain Association in collaboration with the European Commission
  > The European Blockchain Association e. V. identified the potential for better communication, coordination and guidance in the European SSI community. Right now, many enterprises and organisations are building their own SSI solutions by implementing the existing standards and protocols. 

## Background

* [Control over data still a long way off according to research into Self-Sovereign Identity](https://ibestuur-nl.translate.goog/podium/controle-over-data-nog-ver-weg-volgens-onderzoek-naar-self-sovereign-identity?_x_tr_sl=auto&_x_tr_tl=en&_x_tr_hl=nl&_x_tr_pto=nui) 2021-10-20 iBestuur
  > researchers from INNOPAY and TNO argue that in view of the social value of digital data exchange, the government would do well to play a driving role in the further consolidation of the SSI playing field. That starts with creating clarity about the relationship between the Digital Government Act and the EU Digital Identity Wallet.
* [Blockchain-enabled Self-Sovereign Identity](https://www.e-zigurat.com/innovation-school/blog/self-sovereign-identity/) 2021-09-06
  > Martin Schäffner, the initiator of the [EuSSI Working Group](https://europeanblockchainassociation.org/eba-working-group-self-sovereign-identity-eussi/) of the [European Blockchain Association](https://europeanblockchainassociation.org/) and expert in Self-Sovereign Identity, explains the concept of Self-Sovereign Identity and how it differentiates from conventional digital identities.
* [The Roles of Government & The Private Sector in a Digital ID Program with Sebastian Manhart](https://northernblock.io/roles-of-government-and-private-sector-in-digital-id/) 2021-08-13 Northern Block
  > we dive into what’s happening within the Digital ID landscape within Europe. Sebastian Manhart is very well positioned between policy and technology in the European Union. In this episode of SSI Orbit, he shares his experiences and future projections.
* [Data Sovereignty and Trusted Online Identity](https://beyondstandards.ieee.org/data-sovereignty-and-trusted-online-identity/) 2021-07-28 IEEE Beyond Standards
  > A third path could involve handing back some control to citizens. One example of such an approach is the European Self Sovereign Identity Framework developed by the EU Commission. Here the control lies neither with a centralized government service nor with private companies, but is given to the citizens.
* [EU report signposts route to blockchain ID verification](https://www.globalgovernmentforum.com/eu-report-signposts-route-to-blockchain-id-verification/) 2019-05-30
  > But the report maps out a path to improving the current digital ID landscape, in which citizens typically use a huge range of systems to access public and private services. “It is now possible to build new identity frameworks based on the concept of decentralised identities,” its authors write, setting out six recommendations for public sector business owners and digital professionals.
* [EU Report Considers Blockchain-Based Digital Identities, Tokenized National Currencies](https://cointelegraph.com/news/eu-report-considers-blockchain-based-digital-identities-tokenized-national-currencies) 2018-12-07
  * [BLOCKCHAIN FOR GOVERNMENT AND PUBLIC SERVICES](https://www.eublockchainforum.eu/sites/default/files/reports/eu_observatory_blockchain_in_government_services_v1_2018-12-07.pdf) EU Blockchain Forum
* [EU BLOCKCHAIN OBSERVATORY AND FORUM—Workshop Report e-Identity](https://www.eublockchainforum.eu/sites/default/files/reports/workshop_5_report_-_e-identity.pdf) 2018-11-07
* [Government services and digital identity](https://www.eublockchainforum.eu/sites/default/files/research-paper/20180801_government_services_and_digital_identity.pdf) 2018-08-01 EUBlockchainForum
  > The theme of this paper is the use of blockchain and distributed ledger technology for government services, and digital identity in relation to those. The scope for the state-of-the-art is global, but conclusions and recommendations focus on the significance and barriers in the European context.

### Bundlesblok Position Paper

* [A position paper on blockchain enabled identity and the road ahead](https://www.bundesblock.de/wp-content/uploads/2018/10/ssi-paper.pdf) 2018-10 Identity Working Group of the German Blockchain Association [[article](https://www.bundesblock.de/2018/10/23/position-paper-self-sovereign-identity/)]
  > **_Appendix VII – Pilot Projects and Proof of Concepts_**
    * **TrustNet (Finland)** a heavily industry-networked research project that focuses on developing a blockchain-based distributed environment for personal data management following the MyData principles.
    * **Alastria (Spain)** allowing citizens to have control over their personal information in a transparent way following the guidelines set by the European Union.
    * **Blockchain on the Move (Antwerp, Belgium)** explores the potential of SSI for e-Government use cases and State-issued credentials for private sector B2B and B2C use cases.
    * **City of Zug (UPort and ti&m)** users can now pay their parking fees, register for elections or perform online sign on for e-government services.
    * **Danube Tech (Austria)** 3 banks, an insurance company, the Austrian Post, and an institution representing notaries has cooperated to implement a range of use cases based on DIDs, Verifiable Credentials, Sovrin, and the XDI protocol.