---
title: European Blockchain Services Infrastructure (EBSI) and the eSSIF 
description: a peer-to-peer network of interconnected nodes running a blockchain-based services infrastructure, run by members of the European Blockchain Partnership.
excerpt: > 
  The European Blockchain Services Infrastructure aims to deliver EU-wide cross-border digital public services using blockchain technology. The EBSI will materialize as a network of distributed nodes across Europe (the blockchain), leveraging an increasing number of applications focused on specific use cases.
layout: single
categories: ["Government"]
tags: ["Policy","Europe","EU","EBSI","ESSIF","GDPR","VIDChain","ValidatedID","Danube","Walt ID","Thales","CIMEA Naric","DXCTechnology","Identyum","Real World","Interop","Education"]
canonical_url: 'https://decentralized-id.com/government/europe/eu/ebsi-essif/'
redirect_from: 
  - /government/europe/eSSIF/
permalink: government/europe/eu/ebsi-essif/
last_modified_at: 2023-06-09
---

## Main

* [European Blockchain Services Infrastructure (EBSI)](https://digital-strategy.ec.europa.eu/en/policies/european-blockchain-services-infrastructure) 2023-02-14
  > The European blockchain services infrastructure (EBSI) consists of a peer-to-peer network of interconnected nodes running a blockchain-based services infrastructure. Each member of the European Blockchain Partnership (EBP) – the 27 EU countries, Norway, Liechtenstein and the European Commission – will run at least one node.
  > 
  > The infrastructure is made up of different layers including:
  > - a base layer containing the basic infrastructure, connectivity, the blockchain and necessary storage;
  > - a core services layer that will enable all EBSI-based use cases and applications; 
  > - additional layers dedicated to use cases and specific applications.

## Development
* [EBSI developers hub](https://api-pilot.ebsi.eu/docs)
  > A one-stop shop for EBSI application providers to discover our specs, then build and test their solutions.
* [EBSI Wallet Conformance Testing](https://api-conformance.ebsi.eu/docs/wallet-conformance)
  > With the EBSI Conformance Seal, your wallet will be recognized as a trusted and reliable tool for digital transactions across Europe.

## About

* [About ESSIF framework](https://docs.essif.sk/en/about-essif-framework/) eSSIF Network
  > **ESSIF aims to be GDPR compliant while aligning with eIDAS** to ensure that ESSIF can leverage existing legal frameworks, enabling ESSIF to provide digital evidence supporting legal enforceability. All this in line with the revision of eIDAS, which aims to “improve its effectiveness, extend its benefits to the private sector and promote trusted digital identities for all Europeans and create a secure and interoperable European digital identity that puts citizens in control.”
* [European Commission adopts decision to license European Blockchain Services Infrastructure software as open-source](http://web.archive.org/web/20220712093455/https://ec.europa.eu/digital-building-blocks/wikis/display/EBSI/European+Commission+adopts+decision+to+license+European+Blockchain+Services+Infrastructure+software+as+open+source) 2022-07-12
  > The Decision to make EBSI software available for licencing under the [European Union Public Licence](https://commission.europa.eu/content/european-union-public-licence_en) is an example of how the European Commission is not only using, but also contributing to the open-source community and thereby growing the ecosystem around EBSI.
* [5 reasons why professionals and enthusiasts of Self-Sovereign Information Sharing should look into EBSI](https://ec.europa.eu/newsroom/cef/newsletter-archives/40411) 2022-08
  > The web is increasingly more distributed, and with it, a new pattern of information sharing is emerging: Self Sovereign Information sharing, where citizens stay in control of their information by choosing what and when to disclose it, and to whom EBSI enables self-sovereign Citizen-to-Government (C2G) and C2B (Citizen-to-Business) privacy-preserving information sharing.
* [Video] [Verifiable Credentials explained](https://www.smartdegrees.es/en/verifiable-credentials-explained/) 2022-03-13 Smart Degrees
  > Verifiable Credentials, its infrastructure ([European Blockchain Services Infrastructure](https://ec.europa.eu/ebsi), EBSI), and the vast opportunities that it currently provides, through a user’s journey (“Eva’s trip”).
* [Presentation] [EBSI Explained](https://northsearegion.eu/media/16680/ebsi-explained-by-daniel-du-seuil.pdf) 2021-03-03 Daniel du Seuil
  > Our ambition is to establish global leadership in blockchain and distributed ledger technologies
  > - Joined-up political vision (EU-MS)
  > - Public-private partnership
  > - Connecting Global Expertise
  > - Investing in EU Innovation and start-ups
  > - Promoting an enabling DSM
* [Video] [Experience the future with the European Blockchain Services Infrastructure (EBSI)](https://www.youtube.com/watch?v=m2uj7fgb2JI) EBSI 2019-11-28
  > The European Blockchain Services Infrastructure aims to deliver EU-wide cross-border digital public services using blockchain technology. The EBSI will materialize as a network of distributed nodes across Europe (the blockchain), leveraging an increasing number of applications focused on specific use cases. 

## Pilots
* [Verification of Education Credentials on European Blockchain Services Infrastructure (EBSI): Action Research in a Cross-Border Use Case between Belgium and Italy](https://www.mdpi.com/2504-2289/7/2/79) 2023-03 Evrim Tan, Ellen Lerouge, Jan Du Caju, Daniël Du Seuil
  >  The pilot tested and assessed the verification of education credentials through the EBSI blockchain in a cross-border setting between a Belgian and an Italian university. The research was based on action research with the ICT units of the participating universities, wallet solution providers, the Belgian government, and EBSI officials. The findings highlight the following as key challenges for the wider adoption of the EBSI and verification credential use case: (1) onboarding of the EBSI ecosystem governance, (2) issuance of EBSI-compliant digital wallets and data schemes for transcript validation, (3) interoperability issues concerning digital identity systems.
* [EBSI Demo Day](https://ec.europa.eu/digital-building-blocks/wikis/display/EBSI/EBSI+Demo+Day) 2022-08-21 ([presentation](https://ec.europa.eu/digital-building-blocks/wikis/download/attachments/464979566/EBSI_Demo_Day.pdf)) ([playlist](https://www.youtube.com/playlist?list=PLPMb0otsCuFLpE4UYiAZ_y3HhP2VX6q8O)
  > first time since the launch of [the Early Adopters Programme](https://ec.europa.eu/digital-building-blocks/wikis/x/DABXGw) in 2021, we are ready to showcase, in real-time and with real data, the outcomes of the EBSI multi-university pilot.
* [GATACA joins EU Commission’s Early Adopters Program as SSI provider in the Spanish group](https://gataca.io/blog/gataca-joins-the-european-commission-s-early-adopters-program-as-the-ssi-technology-provider-in-the-spanish-group/) 2021-04-12 Gataca
  > In Spain, three universities will pioneer the issuance of digital Academic Diplomas. The issuance will be performed 100% online, where students will authenticate themselves using a digital ID previously issued by FNMT (the Royal Mint of Spain) and stored in their mobile wallets.

## Ecosystem
* [Congrats to the 11 wallet providers for being conformant to @EU_EBSI](https://mobile.twitter.com/IgrantIo/status/1532036324882104321/photo/1) 2022-06-01 IgrantIo
  > We are glad to be among the first few along with [@ValidatedID](https://mobile.twitter.com/ValidatedID) [@danube](https://mobile.twitter.com/danube) [@GATACA_ID](https://mobile.twitter.com/GATACA_ID) [@walt_id](https://mobile.twitter.com/walt_id) [@DXCTechnology](https://mobile.twitter.com/DXCTechnology) [@CIMEA_Naric](https://mobile.twitter.com/CIMEA_Naric) [@identyum](https://mobile.twitter.com/identyum) [@ThalesDigiSec](https://mobile.twitter.com/ThalesDigiSec) [@posteitaliane](https://mobile.twitter.com/posteitaliane)
* [Validated ID's journey to becoming EBSI compliant](https://www.validatedid.com/post-en/validated-ids-journey-to-becoming-ebsi-compliant) 2022-03-10
  > We at Validated ID have been betting on EBSI since the beginning. We started working to become conformant wallet providers since the very first version of [Wallet Conformance Tests (WCT)](https://ec.europa.eu/digital-building-blocks/wikis/display/EBSI/EBSI+wallets) was published. The process of preparing our solution to become conformant has allowed us to appreciate how remarkable EBSI's work has been.
* [VIDchain is the first ID wallet to become EBSI compliant](https://www.validatedid.com/post-en/vidchain-is-the-first-id-wallet-to-become-ebsi-compliant) 2022-01-07 ValidatedID
  * Validated ID participates in a project to build the [European Blockchain Services Infrastructure (EBSI)](https://digital-strategy.ec.europa.eu/en/policies/european-blockchain-services-infrastructure) for the support of cross-border public services, an initiative created by the European Commission. EBSI is developing a strong and mature ecosystem that Validated ID is proud to be part of.
* [Early Adopters Programme - Imagining what EBSI can do for European citizens](https://web.archive.org/web/20220308065848/https://ec.europa.eu/digital-building-blocks/wikis/display/DIGITAL/Digital+Homepage) 2022-03
  > In 2021, 22 projects were selected to become part of our incubator programme to help tap into the potential of the EBSI infrastructure. Each project's private and public sector partners was given early access to the pre-production environment of EBSI, and was invited to develop their own pilot project to address a specific business or government use case involving the exchange of verifiable credentials.
  > 
  > With the help with the EBSI team, Early Adopters can identify how to connect their systems, be part of a community and collaborate with other Early Adopters. This will help us improve EBSI's services and ensure it meets the needs of Europe's businesses and public administrations, within and across borders.
* [Report from EBSI4Austria](https://medium.com/@markus.sabadello/report-from-ebsi4austria-b79c0ed8ab8d) 2021-10-16 Markus Sabadello
  > EBSI4Austria is a CEF funded project with two main objectives. First, EBSI4Austria aims to set up, operate and maintain the Austrian’s EBSI node. Second, we pilot the diploma use case on the Austrian level supported by two Universities and data providers as well as verifiers.
* [EU Grant to Help Building Blockchain Infrastructure](https://sphereon.com/news-and-insights/sphereon-wins-an-eu-essif-lab-grant/) 2021-03-25 Sphereon
  > We’ll be providing a Presentation Exchange that creates interoperability between W3C DIF-compliant Verifiable Credentials and Hyperledger Aries-based Verifiable Credentials for the European Blockchain Services Infrastructure (EBSI).

## European Self-Sovereign Identity Framework (ESSIF)
* [European Self-Sovereign Identity Framework (ESSIF)](http://web.archive.org/web/20210217082613/https://ec.europa.eu/cefdigital/wiki/pages/viewpage.action?pageId=262505734) Europa.eu 2021-01
  > This section contains the documents generated as technical specification for the ESSIF Use Case. These documents act as the base for the architecture definition for ESSIF V1.
  > 
  > The content of this documents should be taken as high-level technical documents, and conceptual technical documents. The content of these documents will be updated as long as the use case implementation evolves.
* [ESSIF: The European self-sovereign identity framework](https://medium.com/@SSI_Ambassador/essif-the-european-self-sovereign-identity-framework-4572f6875e12) 2020-02-03 SSI Ambassador
  > The European self-sovereign identity framework (ESSIF) is part of the European blockchain service infrastructure (EBSI). The EBSI is a joint initiative from the European Commission and the European Blockchain Partnership (EBP) to deliver EU-wide cross-border public services using blockchain technology.
  > 
  > The EBSI aims to become a “gold standard” digital infrastructure to support the launch and operation of EU-wide cross-border public services. It is a multi-blockchain network with multiple use-cases such as notarization of documents, ESSIF, certification of diplomas and trusted data sharing. While there is an EBSI wallet, it’s for test purposes only and not for the public. The consensus of the permissioned network will be achieved via proof of authority (POA) with one note per member state.
* [Understanding the European Self-Sovereign Identity Framework (ESSIF) – Daniël Du Seuil and Carlos Pastor – Webinar 32](https://ssimeetup.org/understanding-european-self-sovereign-identity-framework-essif-daniel-du-seuil-carlos-pastor-webinar-32/) 2019-07-07 SSI-Meetup
  > European Blockchain Partnership (EBP) assists the European Commission in establishing a European Blockchain Services Infrastructure (EBSI). In the short term (2019-2020), the main objective is to start the operation of EU-wide Blockchain-based services and to promote the use of the EBSI in “virtually” every domain of the public sector able to benefit from Blockchain technology. The EBSI has a particular focus on cross-border public services. In 2018, the EBP identified a set of Use-Cases to be implemented on the EBSI one of these important use cases is the European Self Sovereign Identity Framework (ESSIF). The EBSI will implement a generic Self-Sovereign Identity capability that is integrated and interoperable with existing building blocks and legal frameworks like eIDAS and GDPR.
* [Presentation] [European Self Sovereign Identity Framework](https://www.eesc.europa.eu/sites/default/files/files/1._panel_-_daniel_du_seuil.pdf) 2019-01-24 EU Commission
  > In European Blockchain Partnership NL-GER-BE started a initiative on
  > European Self Sovereign Identity framework (eSSIF).
  > ○ How to facilitate cross-border interaction with SSI.
  > ○ How to make/keep national SSI projects interoperable.
  > ○ How to integrate/align existing building blocks such as eIDAS, e-delivery, once-only with SSI.
  > ○ How to conceptualize and build an identity layer in the new European Blockchain Services Infrastructure.
  > ○ How to preserve European/democratic values in the implementation of Self Sovereign identity. 
  ![](https://i.imgur.com/KAMuWHB.png)
