---
title: United Kingdom
layout: single
description: The UK faces a number of digital ID challenges beyond consumer adoption that could slow projects down
excerpt: >
  The government is committed to realising the benefits of digital identity, without creating ID cards. Earlier this year we published a draft of the UK digital identity and attributes trust framework. This document sets out what rules and standards are needed to protect people’s sensitive identity data when used digitally
permalink : /government/europe/united-kingdom/
canonical_url: https://decentralized-id.com/government/europe/united-kingdom/
categories: ["Government"]
tags: ["Policy","Europe","UK","NHS","Digital Staff Passport","Real World"]
last_modified_at: 2023-06-09
toc: false
---

## Government
* [Information Commission’s (ICO) Children’s Code](https://ico.org.uk/for-organisations/guide-to-data-protection/ico-codes-of-practice/age-appropriate-design-a-code-of-practice-for-online-services/) 2023-07-07 UK 
  > officially known as the“Age Appropriate Design Code: a code of practice for online services,” after a year grace period, goes into effect Thursday, Sept. 2, 2021.
* [Digital identity and attributes consultation](https://www.gov.uk/government/consultations/digital-identity-and-attributes-consultation/digital-identity-and-attributes-consultation) 2023-02-03 Gov UK
  > The government is committed to realising the benefits of digital identity, without creating ID cards. Earlier this year we published a draft of the [UK digital identity and attributes trust framework](https://www.gov.uk/government/publications/the-uk-digital-identity-and-attributes-trust-framework). This document sets out what rules and standards are needed to protect people’s sensitive identity data when used digitally. We will put in place the necessary framework and tools so that digital identity products enhance privacy, transparency, confidence and inclusion, and that users are able to control their data, in line with the principles published in the [2019 Call for Evidence response](https://www.gov.uk/government/consultations/digital-identity/outcome/digital-identity-call-for-evidence-response). We are also developing and piloting a new ‘One Login for Government’ system that will make it easier for everyone to access government services, with users only having to provide data to prove their identity once, and protecting privacy throughout.
* [UK digital identity & attributes trust framework alpha v2 (0.2) - Policy Paper](https://www.gov.uk/government/publications/uk-digital-identity-attributes-trust-framework-updated-version/uk-digital-identity-and-attributes-trust-framework-alpha-version-2) 2023-01-26
  > Identity service providers can be authorised by a user to share the verified digital identity with relying parties. The relying party can then use this to give them access to the service or create an account. Other identity service providers might choose to create an account associated with a user’s identity. The user can then use and reuse this account to do different things with different relying parties. For example:
  > - identity verification services (which offers a point in time verification, and the user may or may not have an account)
  > - reusable digital identity services with an account and authentication (federated, self sovereign identity (SSI), wallet), and
  > - reusable authentication services with an account and authentication (federated, SSI, wallet).
* [Data A New Direction](https://assets.publishing.service.gov.uk/government/uploads/system/uploads/attachment_data/file/1016395/Data_Reform_Consultation_Document__Accessible_.pdf) Gov.Uk 2021-09-10
  > ● secure the UK's status as a global hub for the free and responsible flow of personal data - complementing our ambitious agenda for new trade deals and data partnerships with some of the world’s fastest growing economies
  > ● reinforce the responsibility of businesses to keep personal information safe, while empowering them to grow and innovate
  > ● ensure that the ICO remains a world-leading regulator, enabling people to use data responsibly to achieve economic and social goals
* [Plans for governing body to make digital identities as trusted as passports](https://www.gov.uk/government/news/plans-for-governing-body-to-make-digital-identities-as-trusted-as-passports) 2021-07-19 Gov.UK
  > The consultation sets out how the government can build confidence in digital IDs so they have a similar status in law as physical proofs of identity that businesses and individuals already trust.

## Explainer
* [Signs of life: authentication and digital ID in Web 3.0](https://www.raconteur.net/insights/harnessing-the-digital-id-paradigm-shift/) 2023-03-28 Raconteur
  > The UK faces a number of digital ID challenges beyond consumer adoption that could slow projects down, particularly when it comes to government-backed programmes. IT and business consulting firm Netcompany was one of a number of firms involved in the NHS Covid Pass scheme, which highlighted the complexity that sits behind any government system in the UK.
  > 
  > “The UK struggles more than some other European countries because we don’t have a unique digital identifier, and that does make it very difficult when you’re trying to deliver something new,” says Richard Davies, UK managing partner at Netcompany, which is also working on the EU digital ID scheme. "You’re effectively having to stitch together or at least navigate what’s under the covers."
* [ICO’s Child Protection Rules Take Effect Sept. 2, 2021. Are You Ready?](https://identitypraxis.com/2021/09/01/icos-child-protection-rules-take-effect-sept-2-2021-are-you-ready/) 2021-09-01 Identity Praxis 
  > The code is designed to ensure that service providers of apps, programs, toys, or any other devices that collect and process children’s data “are appropriate for use by, and meet the development needs of, children.” It calls for 15 independent and interdependent legal, service design, and data processing principles and standards to be followed. Specifically, as called out in the code, these are:
  > - Best interests of the child 
  > - Data protection impact assessments 
  > - Age appropriate application
  > - Transparency 
  > - Detrimental use of data 
  > - Policies and community standard 
  > - Default settings 
  > - Data minimization 
  > - Data sharing 
  > - Geolocation 
  > - Parental controls 
  > - Profiling 
  > - Nudge techniques 
  > - Connected toys and devices 
  > - Online tools
* [UK Draft Digital Identity Framework Published](https://www.research-live.com/article/news/uk-draft-digital-identity-framework-published/id/5087382) 2021-08-03 Research Live
  > Updates to the framework include new guidance on creating a consistent approach on user experience, rules on how to manage digital identity accounts, clearer definitions for the framework’s role and details on how organisations will be certified.
* [Advances in health "must ensure self-sovereign identity"](https://healthcareglobal.com/digital-healthcare/advances-health-must-ensure-self-sovereign-identity?page=1) 2021-07-23 Healthcare Global
  > Meanwhile [a new report](https://orchahealth.com/patients-seek-digital-health-to-reduce-pressure-on-the-nhs/) has found that the majority of the British public is willing to embrace digital healthcare tools  such as apps and digital therapies prescribed by a trusted healthcare professional.
  > 
  > Shaw adds: “The vital point to make is this: innovations in health technology must ensure self-sovereign identity.
* [Lord Holmes discusses state of digital identity in the UK](https://www.biometricupdate.com/202107/lord-holmes-discusses-state-of-digital-identity-in-the-uk) 2021-07
  > [The next iteration of the framework](https://www.biometricupdate.com/202103/uk-government-runs-new-digital-id-system-pilot-for-public-services) mentioned earlier is due to be published this summer and I look forward to that. It will be essential for that work to not only be underpinned by the twelve guiding principles but also to swiftly ‘sandbox’, stand up parallel proofs in specific sectors and proceed with pace.
* [Digital identity in the UK in 2021 with TrueProfile.io’s René Seifert](https://www.ubisecure.com/podcast/digital-identity-uk-2021-ssi-trueprofile-rene-seifert/) 2021-01-20 (podcast)
  > In episode 37, René Seifert talks about the current status of identity in the UK; the government’s recent call for evidence and DIU (digital identity unit); the resultant six guiding principles – including privacy and inclusivity; the potential of self-sovereign identity to solve some of these issues; TrueProfile.io and the importance of verified credentials in an HR context; plus the ethical, political and technical challenges of ‘immunity passports’.

## Digital Staff Passport - NHS

* [NHS England Transformation Directorate - Digital staff passport](https://transform.england.nhs.uk/information-governance/guidance/digital-staff-passport/) 2022-06-22
  > This guidance provides a summary of the information governance (IG) steps which need to be taken so that the Digital Staff Passport can be set up safely and efficiently within an NHS organisation. This allows authorised staff to temporarily work at another NHS organisation more quickly and safely. Digital Staff Passports are not available in social care organisations.
* [A Digital Staff Passport for hospital facilities, DIZME voted best solution at SHACK22 hackathon](https://infocert.digital/a-digital-staff-passport-for-the-safe-mobility-of-staff-in-hospital-facilities-dizme-has-been-voted-as-the-best-solution-at-shack22-hackathon/) 2022-07-08 Infocert
  > The hackathon held by INTEROPen, a leading organization to support & accelerate the delivery and adoption of Interoperability Standards in health & social, in partnership with NHS (National Health System) was aimed at developing innovative solutions for the management of access and safe mobility of staff in hospital facilities.
* [Literature] [Implementing Self-Sovereign Identity (SSI) for a digital staff passport at UK NHS](https://cpb-us-e1.wpmucdn.com/wordpressua.uark.edu/dist/5/444/files/2018/01/BCoE2022SS1FINAL.pdf) 2022-01 Mary Lacity Walton, Erran Carmel
  > Self-sovereign identity (SSI) is an idea, a movement, and a decentralized approach for establishing trust online. Many standards-making bodies, open-source working groups, and organizations have been working on SSI and verifiable credentials for years. Although production-ready solutions remain in the developmental stage, business executives, professionals, and students need to start learning about what’s ahead. Business practitioners want to know what is unique about SSI. Is there anything idiosyncratic about managing an SSI project compared to other digital projects? How can we apply SSI to deliver business value? We help to answer those questions by explaining SSI through a case study at UK National Health Service (NHS). NHS developed a digital staff passport to verify health professionals’ qualifications and credentials so that healthcare staff could be moved around quickly during COVID-19. While SSI provides some unique capabilities, it does not require unique project management practices. Like all digital projects, the aim was to build capabilities and design for interoperability to avoid vendor lock-in. Building on its early success, NHS intends to expand the application to enable its strategic people plan.
* [Building an SSI Ecosystem: Digital Staff Passports at the NHS](https://www.windley.com/archives/2021/05/building_an_ssi_ecosystem_digital_staff_passports_at_the_nhs.shtml) 2021-05
  > How does a functioning credential ecosystem get started? This post goes deep on Manny Nijjar’s work to create a program for using digital staff passports in the sprawling UK NHS bureaucracy.
* [SSI For Healthcare: Lessons from the NHS](https://vimeo.com/543285754) 2021-04-29 Evernym
  > - Lessons learned from working with self-sovereign identity (SSI) at the NHS, and the needs highlighted when leading the frontline response during COVID-19
  > - What digital health passes mean for the adoption of SSI
  > - Applying the four principles of healthcare ethics to verifiable credential technology
  > - The top use cases for healthcare, including “staff passports” and portable health records

## Organization
* [6 months of KI Identity Assurance in the UK](https://kantarainitiative.org/2022/09/29/6-months-of-ki-identity-assurance-in-the-uk/) 2022-09-29 Kantara Initiative 
  > We believe it is vital that certification bodies work with DCMS and UKAS in a spirit of partnership – bringing together the cumulative value of dozens of great minds! To this end, we have  been encouraged by the proactive approach of DCMS in creating forums where the 5 certification bodies can discuss ideas and feedback on the program in action.
