---
date: 2020-01-07
title: Hyperledger Aries
excerpt: >
  One of the architectural components of Indy is called an Agent. This is software that acts on behalf of an identity owner to communicate off-ledger with other Agents. As Agent work continued with the development of message encryption standards, extensible message typing, and common protocols, interest grew in applying these concepts and practices to systems based on other ledgers. It became clear that the right future for Agent work was to extract it from Indy project and add support for other ledger technologies to make that integration easier and more powerful. That work is now known as Hyperledger Aries.
categories: ["Open Source Projects"]
tags: ["Aries","Blockchain","Bitcoin","Verifiable Organizations Network","DKMS","Indy"]
permalink: /projects/hyperledger/aries/
canonical_url: "https://decentralized-id.com/projects/hyperledger/aries/"
redirect_from: 
  - blockchain/hyperledger/aries/
  - organizations/hyperledger/aries/
  - hyperledger/aries/
last_modified_at: 2023-06-12
---

## About
* [Introduction to Hyperledger Sovereign Identity Blockchain Solutions: Indy, Aries & Ursa](https://training.linuxfoundation.org/training/introduction-to-hyperledger-sovereign-identity-blockchain-solutions-indy-aries-and-ursa/) 2020-09-03 (LFS172)
* [Hyperledger Aries is the Present and the Future of Internet-Scale Trusted Verifiable Credential Ecosystems](https://indicio.tech/hyperledger-aries-is-the-present-and-the-future-of-internet-scale-trusted-verifiable-credential-ecosystems/) 2022-09-13 Indicio
  > While no technology runs perfectly on every device, a signal strength of Aries, AnonCreds, and Indy is that they work on the vast majority of current devices and systems, including $35 smart phones and low powered IOT/embedded devices. They represent the most inclusive way into this technology, which is an important factor in their popularity.
* [Hyperledger Aries Graduates To Active Status](https://www.hyperledger.org/blog/2021/02/26/hyperledger-aries-graduates-to-active-status-joins-indy-as-production-ready-hyperledger-projects-for-decentralized-identity) 2021-02-26
  > The TSC commended the Aries project during the meeting for the project’s highly diverse contributors. Achieving a high number of organizations contributing to a project at Hyperledger is often a challenge. Congratulations are due to those participating in and supporting the Aries Project.
* [Hyperledger Aries to Enable Blockchain-Agnostic, Self-Sovereign Identity](https://medium.com/@xragrawal/hyperledger-aries-to-enable-blockchain-agnostic-self-sovereign-identity-a7d523064112) 2019-07-16 Ravikant Agrawal
  > In two years since the introduction of Hyperledger Indy in 2017 [...] To clarify and keep track of new and existing peer-to-peer interaction code for secrets management, verifiable information exchange, and secure messaging across different blockchains and other distributed ledger technologies, Hyperledger Aries was set in motion.
* [Hyperledger Aries: Open Source Interoperable Identity Solution – Nathan George – Webinar 30](https://ssimeetup.org/hyperledger-aries-open-source-interoperable-identity-solutions-nathan-george-webinar-30/) 2019-06-18 SSI Meetup
  > Aries will be the industry’s first implementation of interoperable open source wallets for digital credentials that use the DKMS (Decentralized Key Management System) architecture that Evernym pioneered under a contract with the U.S. Department of Homeland Security.
* [Hyperledger Aries: The Next Major Step Towards Interoperable SSI](https://www.evernym.com/blog/hyperledger-aries/) 2019-05-30 Evernym
  > Aries was born out of the work on identity agents and identity wallets that began in the Hyperledger Indy project. As a company focused entirely on decentralized identity, Evernym was one of the original founders of the Sovrin Network and contributed the first code to the open source project Hyperledger Indy.
* [Sovrin proudly contributes to Hyperledger Aries](https://sovrin.org/sovrin-proudly-contributes-to-hyperledger-aries/) 2019-05-21
  > In addition to being able to support more ledger technologies than just Indy, Aries can work with multiple ledgers at the same time. This allows Agents to use each ledger according to the unique power offered by each, instead of requiring anchoring to only one ledger. In the future, Agents will be able to integrate not only with the recently announced Ion DID method, but also Ethereum, Hyperledger Sawtooth, Bitcoin, Hyperledger Fabric, and others.
* [Announcing Hyperledger Aries, infrastructure supporting interoperable identity solutions!](https://www.hyperledger.org/blog/2019/05/14/announcing-hyperledger-aries-infrastructure-supporting-interoperable-identity-solutions) 2019-05-14 Hyperledger Foundation
  > Hyperledger Aries, the newest Hyperledger project (the13th!), is a shared infrastructure of tools that enables the exchange of blockchain-based data, supports peer-to-peer messaging in various scenarios, and facilitates interoperable interaction between different blockchains and other distributed ledger technologies (DLTs).

## Ecosystem
* [Hyperledger SSI Ecosystem](https://dev.to/jakubkoci/hyperledger-ssi-ecosystem-4j2p) 2022-08-16 Jakubkoci
  > There are three projects under the Hyperledger umbrella related to digital identity. Hyperledger Indy, Aries, and Ursa. [...] describe their purpose and how they’re related to each other.
* [Learnings from Aries, Indy and Various Verifiable Credential Implementations](https://northernblock.io/learnings-from-aries-indy-and-various-verifiable-credential-implementations/) 2022-08-13 Northern Block
  > 1. The various elements are evolving with the community to address specific use cases, and interdependencies between them are being eliminated to allow for ultimate flexibility and interoperability, where required.
  > 2. Convergence seems to be happening across various elements of the ecosystem. Standards such as OIDC and mDL are all now in dialogue with W3C, AnonCreds, Aries, etc. Mobile is a predominant technology, just like the way laptops were once upon a time. To reduce consumer friction and drive adoption, convergence of all these different technologies is required inside a mobile environment
* [Aries Agent Test Harness Enhancement Project](https://www.idlab.org/en/aries-agent-test-harness-enhancement-project/) 2022-07-27 IDLab
  > To enable interoperability in the Aries VC ecosystem, a number of standards are defined in the form of Request for Comments (RFC).  These RFCs are grouped into Aries Interop Profiles (AIP). These profiles, in turn, define which group of RFCs an agent has to conform to, in order to be labelled AIP compliant.
* [Indicio Wins British Columbia Code With Us Challenge to Upgrade Hyperledger Indy](https://indicio.tech/indicio-wins-british-columbia-code-with-us-challenge-to-upgrade-hyperledger-indy/) 2022-01-18 Indicio
  > Most of Hyperledger Indy’s development occurred prior to the completion of the standard DID Specification by the W3C and, as a result, identifiers written to one network are currently not resolvable on other networks. A new did:indy DID Method will fix that and make it easier for decentralized identity products and services to interoperate across different Indy networks.
* [SITA uses blockchain, decentralized identity for pilot license verification](https://www.ledgerinsights.com/sita-blockchain-decentralized-identity-for-pilot-license/) 2021-11-16 Ledgerinsights
  > Using the [self-sovereign identity](https://www.ledgerinsights.com/tag/self-sovereign-identity/) solution Hyperledger Aries, almost everything works peer to peer between the license issuer and the pilot and between the pilot and the verifier.
* [Indicio.Tech releases Aries Mediator Agent](https://indicio.tech/blog/indicio-tech-advances-decentralized-identity-with-release-of-critical-open-source-technology/) 2020-12-31
  > The Indicio Mediator Agent is the company’s latest contribution to Aries Cloud Agent Python (ACA-Py) and the Aries Toolbox. Following RFC 0211: Mediator Coordination, Indicio built on the work of the open-source community to make mediation interoperable and vendor agnostic. This expands the opportunities for mobile wallet implementations.
  > *[...]*
  > Indicio.tech is committed to becoming a resource-hub for decentralized identity, providing enterprise-grade open source tools to its clients and to the community. This includes the [Private Networks](https://indicio.tech/private-networks/) build service, the [Indicio TestNet](https://indicio.tech/indicio-testnet/), and a variety of customizable [training programs](https://indicio.tech/training-packages/).

## Code

* [hyperledger/aries](https://github.com/hyperledger/aries)
  > Hyperledger Aries is infrastructure for blockchain-rooted, peer-to-peer interactions
* [hyperledger/aries-cloudagent-python](https://github.com/hyperledger/aries-cloudagent-python) 2023-06-10
  > Hyperledger Aries Cloud Agent Python (ACA-Py) is a foundation for building decentralized identity applications and services running in non-mobile environments.
* [hyperledger/aries-framework-dotnet](https://github.com/hyperledger/aries-framework-dotnet) 2023-05-26
* [hyperledger/aries-acapy-plugin-toolbox](https://github.com/hyperledger/aries-acapy-plugin-toolbox) 2023-03-07
  > Aries Cloud Agent - Python plugin for the Aries Toolbox
* [hyperledger/aries-staticagent-python](https://github.com/hyperledger/aries-staticagent-python) 2022-10-20
* [hyperledger/aries-protocol-test-suite](https://github.com/hyperledger/aries-protocol-test-suite) 2021-02-20
  > Test Suite for testing protocol compliance of Aries Agents
* [TelegramSam/aries-toolbox](https://github.com/TelegramSam/aries-toolbox) 2020-09-09 - tool for interacting with Agents

## Development
* [hyperledger/aries-rfcs](https://github.com/hyperledger/aries-rfcs)
* [hyperledger/indy-hipe/text/0002-agents](https://github.com/hyperledger/indy-hipe/tree/master/text/0002-agents) 2019-06-20 Hyperledger Foundation
  > - A mobile app that Alice uses to manage credentials and to connect to others is an agent for Alice.
  > - A cloud-based service that Alice uses to expose a stable endpoint where other agents can talk to her is an agent for Alice.
  > - A server run by Faber College, allowing it to issue credentials to its students, is an agent for Faber.
  > 
  > Having a tight definition of an agent may not matter in all cases. However, it is important when we are trying to understand interoperability goals. We want agents to be able to interact with one another. Does that mean they must interact with every piece of software that is even marginally agent-like? Probably not.
* [Becoming a Hyperledger Aries Developer](https://training.linuxfoundation.org/training/becoming-a-hyperledger-aries-developer-lfs173/) Linux Foundation
  > Learn how to develop blockchain-based production-ready identity applications with Hyperledger Aries in this free course.
* [Becoming an Indy/Aries Developer](https://github.com/hyperledger/aries-cloudagent-python/blob/main/docs/GettingStartedAriesDev/README.md) 2023-02-22
      > Hyperledger Aries Cloud Agent Python (ACA-Py) is a foundation for building decentralized identity applications and services running in non-mobile environments.
* [Introducing Hyperledger Aries Framework JavaScript 0.2.0](https://www.hyperledger.org/blog/2022/07/06/introducing-hyperledger-aries-framework-javascript-0-2-0) 2022-07-06 Hyperledger 
  > The new Hyperledger Aries Framework JavaScript release (0.2.0) contains some incredible steps forward. Especially in our goal to make the framework AIP 2.0 compliant. AIP 2.0 compliance will not only ensure the framework supports the latest standards and protocols, but it will also greatly increase interoperability and make it more useful outside of the Hyperledger Indy ecosystem.
* [Hyperledger Mentorship Spotlight: Hyperledger Aries Integration to Support Fabric as Blockchain Ledger](https://www.hyperledger.org/blog/2021/12/06/hyperledger-mentorship-spotlight-hyperledger-aries-integration-to-support-fabric-as-blockchain-ledger) 2021-12-06
  > The Hyperledger Mentorship Program is a structured hands-on learning opportunity for new developers who may otherwise lack the opportunity to gain exposure to Hyperledger open source development and entry to the technical community.
* [The Pathway to Becoming a Hyperledger Maintainer](https://www.hyperledger.org/blog/2021/11/03/the-pathway-to-becoming-a-hyperledger-maintainer) 2021-11-03
  > In this blogpost I’m going to share what it’s like to be a maintainer for the Hyperledger Aries project. You’ll learn how you can start contributing and maybe even set yourself on a path to becoming a maintainer.
* [0430 machine readable governance frameworks](https://github.com/hyperledger/aries-rfcs/blob/master/concepts/0430-machine-readable-governance-frameworks/README.md) 2021-10-20
  > Explains how governance frameworks are embodied in formal data structures, so it's possible to react to them with software, not just with human intelligence.
* [Setting up Mediator Agent in Ubuntu — (.Net Core service in Linux Box)](https://rangesh.medium.com/setting-up-mediator-agent-in-ubuntu-net-core-service-in-linux-box-b874bb409eed) 2021-08-04 Rangesh
  > In a Self Sovereign Environment supported by Hyperledger Indy / Aries agent framework, Mediator Agent is one of the essential components that acts as postman service between Issuer /Verifier Aries Agent and Mobile Agent.
* [Aries Cloud Agent Python Code Documentation](https://aries-cloud-agent-python.readthedocs.io/en/latest/) 2021
  > Hyperledger Aries Cloud Agent Python (ACA-Py) is a foundation for building decentralized identity applications and services running in non-mobile environments.
  > 
  > This is the Read The Docs site for the Hyperledger Aries Cloud Agent Python. This site contains only the ACA-Py docstrings documentation extracted from the Python Code. For other documentation, please consult the links in the Readme for the ACA-Py GitHub Repo.
* [GlobaliD releases new open source applications](https://medium.com/global-id/globalid-shares-ssi-code-at-the-internet-identity-workshop-446debec43e7) 2020-10-30
  > They open source their open-sourced iOS and Android native Aries frameworks and donated them to the Hyperledger Aries project.
  > 
  > They also shared their Dynamic Governance API using GlobaliD Groups.
* [Tutorials](https://aries.js.org/guides/0.4/tutorials)  Aries JavaScript Docs
  > First we’re going to create a holder Agent, this will be the Agent that receives the membership credential. During their life, the holder will collect many different verifiable credentials. Memberships, ID-cards, even purchasing records.

