---
title: Sidetree Working Group - DIF
description: "Sidetree is a protocol for creating scalable Decentralized Identifier networks that can run atop any existing decentralized anchoring system"
excerpt: >
  Architecturally, Sidetree-based DID Method implementations are overlay networks composed of independent peer nodes (Sidetree nodes) that interact with an underlying decentralized anchoring system (as illustrated under Network Topology) to write, observe, and process replicated DID PKI state operations using deterministic protocol rules that produce an eventually strongly consistent view of all DIDs in the network. 
layout: single
permalink: /projects/decentralized-identity-foundation/sidetree/
redirect_from:
  -  /organizations/decentralized-identity-foundation/wg/sidetree/
canonical_url: 'https://decentralized-id.com/projects/decentralized-identity-foundation/sidetree/'
categories: ["Open Source Projects"]
tags: ["DIF","Sidetree","ION"]
last_modified_at: 2023-06-12
---

## Main
* [Sidetree Working Group](https://identity.foundation/working-groups/sidetree.html)
  > The development and maintenance of the formal Sidetree specification, and a hub of coordination for Sidetree-based DID Method node operators. This group also generates libraries, tooling, and documentation to aid Sidetree-based DID Method node operators.
  - [Charter](https://github.com/decentralized-identity/org/blob/master/Org%20documents/WG%20documents/DIF_Sidetree_WG_charter_v1.pdf)
  - [Agenda](https://github.com/decentralized-identity/sidetree/blob/master/agenda.md) 
  - [Mailing list](https://lists.identity.foundation/g/sidetree-wg) 
  - [GitHub](https://github.com/topics/wg-sidetree) 
  - [Meetings](https://docs.google.com/spreadsheets/d/1wgccmMvIImx30qVE9GhRKWWv3vmL2ZyUauuKx3IfRmA/edit#gid=1343983492)

## About

* [Decoding the Sidetree Protocol](https://academy.affinidi.com/decoding-the-sidetree-protocol-18d8bfa39257) 2021-05-25 Affinidi
  > Sidetree protocols are layer 2 protocols that anchor to the underlying decentralized ledger system. That said, it is ledger agnostic and its primary role is to anchor batches of signed JSON operations to the network.
* [Sidetree Protocol reaches V1](https://blog.identity.foundation/sidetree-protocol-reaches-v1/) 2021-04-12 DIF
  > This week, the DIF Steering Committee officially approved the first major release of the Sidetree Protocol specification, "v1" so to speak. This protocol has already been implemented, and four of its implementers have been collaborating intensively for over a year on expanding and extending this specification together.
- [Sidetree Protocol / Element DID and Friends](https://iiw.idcommons.net/Sidetree_Protocol_/_Element_DID_and_Friends) 2020-04-30 IIW30
- [Sidetree did:ion + did:elem Roadmap + dev](https://iiw.idcommons.net/Sidetree_did:ion_%2B_did:elem_Roadmap_%2B_dev) IIW29
  > We discussed that it allows the did controller to update their did document, including adding support for experimental features or new key types like GPG and BBS.
  > 
  > Troy from Secure Key explained how they use Sidetree with Hyper Ledger Fabric.
  > 
  > Secure Key uses sidetree for things other than did documents.
  > 
  > Transmute uses Sidetree to store hashlinks to Encrypted Data Vaults / Secure Data Stores as a way of scalably commiting to specific versions of credentials. 
- [Sidetree protocol – Massivly Scalable Decentralized Identifiers – DEEP DIVE](https://iiw.idcommons.net/Sidetree_protocol_%E2%80%93_Massivly_Scalable_Decentralized_Identifiers_%E2%80%93_DEEP_DIVE) IIW28
- [Sidetree on Ethereum “Element](https://iiw.idcommons.net/Sidetree_on_Ethereum_%E2%80%9CElement) 2019-10-08 IIW28
  > ![](https://iiw.idcommons.net/images/e/ea/IIW29_TH_15H_Sidetree_DID-ion%2Bdid-elem_Roadmap_%26_Dev%281%29.jpg)

## Specs & Projects
### Sidetree
* [Sidetree Protocol](https://identity.foundation/sidetree/spec/) 
  > Spec, docs, and implementations for the chain/ledger-agnostic DID scaling protocol.
* [decentralized-identity/sidetree](https://github.com/decentralized-identity/sidetree)
  > Sidetree Specification and Reference Implementation
* [sidetree-ipfs-datastores](https://github.com/decentralized-identity/sidetree-ipfs-datastores) 
  > Implementations of IPFS datastore used by sidetree-ipfs microservice

### ION
* [Install Guide](https://github.com/decentralized-identity/ion/blob/master/install-guide.md)
  >  An implementation of the Sidetree protocol atop the Bitcoin blockchain. 
* [decentralized-identity/ion](https://github.com/decentralized-identity/ion)
  > ION is a public, permissionless, Decentralized Identifier (DID) network that implements the blockchain-agnostic Sidetree protocol on top of Bitcoin (as a 'Layer 2' overlay) to support DIDs/DPKI (Decentralized Public Key Infrastructure) at scale.
* [ion-integration-test](https://github.com/decentralized-identity/ion-integration-test) 
  > An integration test script that helps verify that the sidetree microservices are working properly.
* [ion-sdk](https://github.com/decentralized-identity/ion-sdk) 
  > TypeScript SDK for ION
* [ion-tools](https://github.com/decentralized-identity/ion-tools)
  > Tools and utilities to make working with the ION network and using ION DIDs easy peasy lemon squeezy

[Introduction to Ion – a layer 2 network for Decentralized Identifiers with Bitcoin - Daniel Buchner](https://www.slideshare.net/SSIMeetup/introduction-to-ion-a-layer-2-network-for-decentralized-identifiers-with-bitcoin-daniel-buchner) 2019-06-13 [SSI Meetup](https://ssimeetup.org/introduction-ion-layer-2-network-decentralized-identifiers-bitcoin-daniel-buchner-webinar-29/)
  > Microsoft presented in May 2019 in New York the first decentralized infrastructure implementation by a major tech company that is built directly on the Bitcoin blockchain called Ion. Daniel Buchner, who is leading this initiative at Microsoft and a founding member of the Decentralized Identity Foundation, will discuss the culture at Microsoft, how decentralized identity works with Bitcoin and what you need to know to use the Bitcoin blockchain for non-financial transactions.
  > 
  > Ion handles the decentralized identifiers, which control the ability to prove you own the keys to this data.

<iframe src="//www.slideshare.net/slideshow/embed_code/key/e4v6fZdFL5fdu3" width="595" height="485" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="border:1px solid #CCC; border-width:1px; margin-bottom:5px; max-width: 100%;" allowfullscreen> </iframe> 

### Element
* [Element](https://element-did.com/) - An implementation of the Sidetree protocol using the Ethereum blockchain. [GitHub](https://github.com/decentralized-identity/element)
* [The Element DID Method: Sidetree, Ethereum &amp; IPFS – Orie Steele](https://www.slideshare.net/SSIMeetup/the-element-did-method-sidetree-ethereum-ipfs-orie-steele) 2019-11-10 [SSI-Meetup](https://ssimeetup.org/element-did-method-sidetree-ethereum-ipfs-orie-steele-webinar-31/)
  > Orie Steele is Cofounder and CTO of Transmute, a company developing IAM and Verifiable Credential solutions that integrate Decentralized Identity for Enterprises. He has a BS in Cyber Security and MS in Computer Science from Stevens Institute of Technology where he studied social network malware and botnets between 2007-2012. He was an early engineer at Patient IO, a Techstars backed startup acquired by Athena Health in 2016, where he helped develop and secure a care coordination platform that connected nurses and patients.
  > 
  > In this talk, Orie will discuss the history of the Element DID Method, how it leverages the same Sidetree Protocol that is used by ION on the Bitcoin Network. He’ll introduce the motivation for Element and ION, and then walk through the core components of developing a working DID System, including topics such as wallets, signing, DID resolution, key revocation, and decentralization.

<iframe src="//www.slideshare.net/slideshow/embed_code/key/2ct2imQLUnzp1j" width="595" height="485" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="border:1px solid #CCC; border-width:1px; margin-bottom:5px; max-width: 100%;" allowfullscreen> </iframe> 
