---
title: Trust over IP Foundation - TOIP
description: "Combines cryptographic verifiability with human accountability at the legal, business, and social layers."
excerpt: >
  The mission of this Foundation is to simplify and standardize how trust is established over a digital network or using digital tools (whether online or disconnected). The goal is to create a safe and private space for all digital interactions—whether between individuals, businesses, governments, or any type of “thing” we might digitally interact with.
layout: single
permalink: organizations/trustoverip/
canonical_url: 'https://decentralized-id.com/organizations/trustoverip/'
categories: ["Community Orgs"]
tags: ["Centre","BCGov","GLEIF","Interop","Governance","OIX","Sovrin Foundation","Avast","KABN Network"]
last_modified_at: 2023-07-02
---

## About
* [Video] [View From The Field, Riley Hughes](https://www.youtube.com/watch?v=z3H40QAEJnw&t=2s) 2022-03-23 Trust Over IP
  > Perspectives on the business problems being addressed by ToIP-aligned solutions. Primary research performed by Trinsic to get to the core issues getting in the way of scaling adoption of trust solutions. Riley presents his results and offers perspectives on how to overcome the various challenges.
* [RADIO WITH PICTURES](https://trustoverip.org/blog/2022/03/02/radio-with-pictures/) 2022-03-02 Trust over IP
  > Exploring why human trust should be an essential design element in the next generation of digital solutions
* [“NO, I DON’T TRUST YOU” – IMPLEMENTING ZERO-TRUST ARCHITECTURE IN THE WORLD OF SELF-SOVEREIGN IDENTITY (SSI)](https://trustoverip.org/blog/2022/02/22/no-i-dont-trust-you-implementing-zero-trust-architecture-in-the-world-of-self-sovereign-identity-ssi/) 2022-02-22 Trust over IP
  > Efforts are underway around the globe to promote new trust models between governments and citizens that promotes privacy and improves how trust is established between entities sharing information. Now is the time for the US government to consider and adopt the ToIP Framework as a starting point to not only support ZTA but promote greater privacy in information sharing within its ecosystem.
* [On Forests, Emergence, and Expansive Trust: Why Trust Over IP is even more profound than we thought](https://trustoverip.org/blog/2021/11/21/on-forests-emergence-and-expansive-trust/) 2021-11-21 Daniel Hardman
  > I have been lucky enough to witness many of its milestones — the finalization of the VC and DID specifications, the launch of Sovrin and Hyperledger Indy, the advent of production deployments and serious interoperability, the invention of peer DIDs and KERI and BBS+ credentials, the implementation of the exciting communication technology now known as DIDComm…
* [The Trust Over IP Stack: Achieving Global Interoperability with SSI](https://www.youtube.com/watch?v=YzKfb-udavY) 2020-09-25 Drummond Reed, Identifire 
  > John Jordan, the executive director of the Trust Over IP digital trust service in the province of British Columbia in Canada said, "This is turning into a stack for digital trust, that the TCPIP stack was to the internet, to data exchange. We figured how to do voice over ip right and now we're doing things like zoom voice and video over over that and that became webrtc he said this is doing trust over ip."
* [Presentation] [ToIP Primer](https://trustoverip.org/wp-content/uploads/2020/05/toip_050520_primer.pdf) 2020-05-05\
*A history of procedural trust, leading to an overview of the TOIP stack.*
* [Podcast] [Trust Over IP 101 with John Jordan, André Kudra, Karl Kneis, Scott Perry & Paul Knowles](https://northernblock.io/toip-101/) 2021-05-11 Northern Block
  > As we’re looking to move from the current internet era towards this new era of digital trust, I think it would be helpful if you were able to give an overview of how we got here. Perhaps we can take a step back, before the internet era, and discuss the paper credential era — I think that sets a good framework for where we’re going with these new digital trust models.
* [Video] [What Does Trust Over IP Mean for Governments and Their Citizens?](https://zoom.us/rec/play/mDKBrRGUj438P08UFt48x9aQJJbzEnmx9syvFDX4wqE-CfInHCtlTGHVYZsQbqDvFEHz1384UmDhujnN.gy3Vc_uWCCYptA-C?continueMode=true&_x_zm_rtaid=1wnxNXi8Tt2RA2GEkoKd2w.1608587036943.898bee9a8db5ed8d3cf416dfad4da5bb&_x_zm_rhtaid=942)
  > credentials can help reopen travel, reduce the costs and improve access to healthcare, streamline KYC and financial transactions, and help connect students with employers needing their skills—all while saving governments billions in the costs of connecting and protecting their digital infrastructure.
  > *[...]*
  > featured speakers from Evernym, Mastercard, LG CNS, Accenture, GLEIF, and other[s]

## Organization

* [Introduction to Trust over IP](https://trustoverip.org/wp-content/uploads/Introduction-to-ToIP-V2.0-2021-11-17.pdf) 2021-11-17 Trust over IP
  > The mission of this Foundation is to simplify and standardize how trust1 is established over a digital network or using digital tools (whether online or disconnected). The goal is to create a safe and private space for all digital interactions—whether between individuals, businesses, governments, or any type of “thing” we might digitally interact with.2 The primary tool for achieving this objective is a “stack” roughly analogous to the TCP/IP stack that powers the Internet. However, this stack is not just technology, rather it combines cryptographic verifiability at the machine layers with human accountability at the legal, business, and social layers.
* [TrustOverIP Model](https://trustoverip.org/toip-model/) 2021-07-22 Trust over IP
  > ![](https://trustoverip.org/wp-content/uploads/trust-over-ip-technology-governance-stack-1536x990.jpg)
* [The Trust Over IP Foundation Publishes New Introduction and Design Principles.](https://trustoverip.org/blog/2022/01/24/the-trust-over-ip-foundation-publishes-new-introduction-and-design-principles/) 2022-01-24 Trust over IP
  > 1. [Introduction to ToIP V2.0](https://trustoverip.org/permalink/Introduction-to-ToIP-V2.0-2021-11-17.pdf)
    > This is the second-generation version of our original introductory white paper that would go more deeply into the origin and purpose of the ToIP stack and how it addresses the key challenges of decentralized digital trust infrastructure.
  > 2. [Design Principles for the ToIP Stack V1.0](https://trustoverip.org/permalink/Design-Principles-for-the-ToIP-Stack-V1.0-2022-11-17.pdf)
    > This is an articulation of the key [design principles](https://principles.design/) we must follow in the design and
  > 3. development of all aspects of the ToIP stack.
* [The ToIP Foundation Releases its First Official Governance Specifications](https://trustoverip.org/news/2022/02/01/the-toip-foundation-releases-its-first-official-governance-specifications/) 2022-02-01 Trust Over IP
  > The [ToIP Governance Architecture Specification](https://trustoverip.org/permalink/ToIP-Governance-Architecture-Specification-V1.0-2022-12-21.pdf) V1.0 2022-12-21
  > The [ToIP Governance Metamodel Specification](https://trustoverip.org/permalink/ToIP-Governance-Metamodel-Specification-V1.0-2022-12-21.pdf) V1.0  2022-12-21

## Working Groups

- [Concepts & Terminology Working Group](https://wiki.trustoverip.org/pages/viewpage.action?pageId=65700&src=contextnavpagetreemode)
- [Ecosystem Foundry Working Group](https://wiki.trustoverip.org/display/HOME/Ecosystem+Foundry+Working+Group?src=contextnavpagetreemode)
- [Good Health Pass Working Group*](https://wiki.trustoverip.org/pages/viewpage.action?pageId=73790&src=contextnavpagetreemode)
- [Governance Stack Working Group](https://wiki.trustoverip.org/display/HOME/Governance+Stack+Working+Group?src=contextnavpagetreemode)
  - [Governance Architecture Task Force](https://wiki.trustoverip.org/pages/viewpage.action?pageId=66738)
- [Human Experience Working Group](https://wiki.trustoverip.org/display/HOME/Human+Experience+Working+Group?src=contextnavpagetreemode)
- [Data Modelling and Representation Working Group](https://wiki.trustoverip.org/display/HOME/Data+Modelling+and+Representation+Working+Group?src=contextnavpagetreemode)
- [Inputs and Semantics Working Group (Archive)](https://wiki.trustoverip.org/pages/viewpage.action?pageId=65746&src=contextnavpagetreemode)
- [Technology Stack Working Group](https://wiki.trustoverip.org/display/HOME/Technology+Stack+Working+Group?src=contextnavpagetreemode)
  - [AI & Metaverse Technology Task Force – Home – Confluence (trustoverip.org)](https://wiki.trustoverip.org/pages/viewpage.action?pageId=19657312)
- [Utility Foundry Working Group](https://wiki.trustoverip.org/display/HOME/Utility+Foundry+Working+Group?src=contextnavpagetreemode)

## Ecosystem

* [BCGov improves sustainability reporting with digital trust technology](https://trustoverip.org/blog/2022/08/29/toip-steering-committee-member-the-government-of-british-columbia-improves-sustainability-reporting-with-digital-trust-technology/) 2022-08-29 Trust over IP
  > Digital credentials can be checked in real time, expediting access to trustworthy information. These trusted, verifiable digital credentials are the core digital trust technologies being piloted and the trust ecosystem in which they operate are defined in ToIP architecture, governance, and related documents.
* [Achieving Trusted Digital Transactions Across the Globe: OIX and ToIP Align to make it Happen](https://trustoverip.org/news/2022/06/15/achieving-trusted-digital-transactions-across-the-globe-oix-and-toip-align-to-make-it-happen/) 2022-06-15 Trust over IP
  > With a combined worldwide membership of over 400 organisations and individuals, including some of the world’s largest stakeholders in a digital ID future, this is a crucial development in the journey towards full digital ID adoption and a digital future that will work for everyone involved.
* [THE VERIFIABLE LEI: DELIVERING ON THE PROMISE OF THE TOIP STACK](https://trustoverip.org/blog/2022/02/07/the-verifiable-lei-delivering-on-the-promise-of-the-toip-stack/) 2022-02-07 TOIP, GLEIF
  > It will give government organizations, companies, and other legal entities worldwide the capacity to use non-repudiable identification data pertaining to their legal status, ownership structure and authorized representatives in a growing multitude of digital business activities
* [Trust over IP and Sovrin sign agreement to strengthen collaboration](https://trustoverip.org/news/2021/05/10/trust-over-ip-and-sovrin-sign-agreement-to-strengthen-collaboration/) 2021-05-10 Trust over IP
  > The Sovrin Foundation (“Sovrin”) Board of Trustees and Trust over IP Foundation (“ToIP”) Steering Committee are pleased to announce that they have signed a Letter Agreement (dated March 18, 2021). This agreement signifies the commitment of both organizations to mutual cooperation and recognition for each other’s mandates. Sovrin and ToIP intend to work together toward advancing the infrastructure and governance required for digital trust and digital identity ecosystems.

## Membership

* [Avast Joins Trust over IP as a Steering Member](https://trustoverip.org/news/2022/08/30/avast-joins-the-toip-foundation-as-a-steering-member/) 2022-08-30 Trust over IP
  > “It is finally time we had digital wallets with digital credentials that work exactly the same way our real-world wallets do,” said Mr. Reed. “We can take and use them anywhere to privately prove just what another party needs to know in the context of a particular transaction. We don’t have to go through any third-party gatekeeper to do this. That’s the way it should work in the digital world too.”
* [SCHELLMAN JOINS TRUST OVER IP FOUNDATION AS STEERING COMMITTEE MEMBER](https://trustoverip.org/news/2022/03/25/schellman-joins-trust-over-ip-foundation-as-steering-committee-member/) 2022-03-25 Trust over IP
  > Tampa-based Schellman, a leading provider of attestation and compliance services, announced today that it is joining the Trust over IP Foundation (ToIP) as a Steering Committee member.
* [Press Release] [KABN Network Joins the Trust Over IP Foundation](https://www.accesswire.com/616265/KABN-Network-Joins-the-Trust-Over-IP-Foundation) 2020-12-12 Accesswire
  > KABN aims to use proven bank-grade identity verification processes to allow Holders (who use a credential), Verifiers (who confirm the validity of a credential) and Issuers (who produce the credential) to complete transactions of many kinds including financial services, eCommerce transactions, organization, building and visitor access badges among others.

## Tools

* [LAYER 1 UTILITIES: AN UNDERGROUND NETWORK CONNECTING ALL SSI ECOSYSTEMS](https://trustoverip.org/blog/2022/03/04/layer-1-utilities-an-underground-network-connecting-all-ssi-ecosystems/) 2022-03-04 Trust Over IP
  > - Understand: [A general framework for choosing which Layer 1 Utility and did method to utilise](https://docs.google.com/document/d/10NGAtlov49dbaDX96C0F4MdRrr20eHiE4RSZfJu0oXU/edit#heading=h.3e0mwiwnhg9n)
  > - Compare: [A comparison chart of all Layer 1 Utilities and identity overlay networks](https://docs.google.com/spreadsheets/d/18MpvpFPLjL2I7RSFI44heWrrvf3l9pAArzhznAPFVAQ/edit#gid=0)
  > - Comply: [A guidance document for data protection and GDPR compliance](https://docs.google.com/document/d/11KkdraiY9oASjU-H91MGxJ7-mNyhnCsfNSG4MFq8Qec/edit)
  > - Innovate: DeFi compliance on top of Layer 1 Utilities ([Shyft](https://www.shyft.network/) [Notabene](https://notabene.id/) [Centre](https://www.centre.io/)) payments for Verifiable Credentials ([cheqd](https://www.cheqd.io/)) [Kilt](https://www.kilt.io/) [Velocity](https://www.velocitynetwork.foundation/self-sovereign-identity-ssi-and-the-velocity-network/)) overlay networks ([did:ion](https://identity.foundation/ion/) [did:tz](https://did-tezos-draft.spruceid.com/) [did:orb](https://securekey.com/securekeys-new-ledger-agnostic-solution-orb-helps-solve-decentralized-identifier-challenges/)) [KERI](https://keri.one/) and self-certifying identifiers, self-executable governance (to name a few!) are all Layer 1 Utility innovations on the horizon. Let us know what you’d like to see going forward and how we can build guidance and documentation around it!
* [ToIP Releases Additional Tools for Governance and Trust Assurance in Digital Trust Ecosystems](https://trustoverip.org/news/2021/11/12/toip-releases-additional-tools-for-governance-and-trust-assurance-in-digital-trust-ecosystems/) 2021-11-12 Trust over IP
  > Following the [September announcement of its first tools for managing risk in digital trust ecosystems](https://trustoverip.org/blog/2021/09/23/trust-over-ip-foundation-issues-its-first-tools-for-managing-risk-in-digital-trust-ecosystems/), today the ToIP Foundation announced three more pairs of tools to assist in the task of generating digital governance and trust assurance schemes
* [Trust over IP Foundation Introduces a New Tool for Interoperable Digital Trust](https://trustoverip.org/blog/2020/10/19/trust-over-ip-foundation-introduces-a-new-tool-for-interoperable-digital-trust/) 2020-10-19 Trust over IP
  > To facilitate this new approach to market-driven interoperability, the Technology Stack Working Group of the ToIP Foundation developed the ToIP Interoperability Profile (TIP). A TIP represents a specific combination of technologies that span each of the four layers of the ToIP technology stack in order to meet the requirements of a set of target customers in one or more digital trust ecosystems. 

## Interop

* [Release of the Good Health Pass (GHP) Interoperability Blueprint](https://trustoverip.org/news/2021/08/12/release-of-the-good-health-pass-ghp-interoperability-blueprint/) 2021-08-12 TrustoverIP
  > After a public review period during June with stakeholders in air travel, government, healthcare, hospitality, and other affected sectors, the Blueprint was finalized in mid-July for final approval and publication. “Publication of the V1.0.0 Blueprint is just the first step in seeing interoperable privacy preserving digital health passes adopted in order to support people being able to gather together again with lower personal and public health risk,” said Kaliya Young, chair of the Working Group and Ecosystems Director at CCI. “Our next task is collaborating with real world implementers to fill in any remaining gaps to get to an interoperable system and working with LFPH and other partners to deliver open source code that can be deployed.”
* [LAYER 1 UTILITIES: AN UNDERGROUND NETWORK CONNECTING ALL SSI ECOSYSTEMS](https://trustoverip.org/blog/2022/03/04/layer-1-utilities-an-underground-network-connecting-all-ssi-ecosystems/) 2022-03-04 Trust over IP
  > Please mind the gap between the DID and the DID Document! Just like the London Underground, Layer 1 Utilities are a collection of connected rails and overlapping networks, on top of which SSI ecosystems are developed. The ToIP Utility Foundry Working Group (UFWG) are mapping out how they overlap, intersect and differentiate from each other.
* [TOIP HELPS SANTA WITH HIS TOUGHEST CHOICES](https://trustoverip.org/news/2021/12/15/toip-helps-santa-with-his-toughest-choices/) 2021-12-15 Trust over IP
  > MEGA also joined the Good Elf Pass Initiative whose “interoperability blueprint” supports its crucial role as issuers of these credentials. The ground-breaking “Hypersleigh” blockchain standard will also support rapid delivery and high security for all Meaningful Gifts. #hypersleigh
* [OPN-R (Open Public Notice - Rights) - starting Notice & Control Language - for people to use rights and govern identity (govinterop) with @ Kantara, ToiP and W3C Data Privacy Vocabulary using international vocab - from ISO/IEC 29100 Legal Framework Vocabulary](https://iiw.idcommons.net/22F/_OPN-R_-_Open_Public_Notice_-_Rights_-_starting_Notice_and_Control_Language) by Mark Lizar
  > - International standard vocabulary for security and privacy frameworks provides roles and actors to govern the transfer of personal data.
  > - The active state notice and consent receipt - is a format for generating consent records from notice/policy - which provides people with information to use rights. .
  > - W3C Data Privacy Control Vocabulary and ISO/IEC 29100, Legal Framework Vocabulary

## Economics
* [Self-sovereign identity semantics: An economic extension to the Trust over IP stack](https://blog.verim.id/self-sovereign-identity-semantics-an-economic-extension-to-the-trust-over-ip-stack-4a4197d8f6d3) 2021-05-18\
*Kaliya thinks this is a terrible idea. It is based on the premise that identity providers (issuers of credentials) should get paid every time a person (the holder) presents the credential in their wallet, when shared with the relying party (verifier) I think this is toxic and we are just finally getting to aligned standards for the VC format and for exchange protocols - now some how we are going to rapidly add a payments layer?*
  > As we began creating the tokenomic model and product roadmap for cheqd, we quickly hit a disconnect between the identity and public blockchain communities. In short, each community uses different semantics. Nowhere is this more evident than in the meaning of “Layer 2” which has wildly different meanings between the two communities.

## Retrospective
* [A YEAR IN REVIEW: NEW BEGINNINGS AND SUCCESSES](https://trustoverip.org/blog/2021/10/07/a-year-in-review-new-beginnings-and-successes/) 2021-10-07 Trust over IP
  > The TSWG provides guidance and specifications that support the ToIP 4-layer model from a technical standpoint.
* [Key ToIP Take Aways from EIC](https://trustoverip.org/blog/2022/06/03/key-toip-takeaways-from-the-european-identity-conference/) 2022-06-03 TOIP

