---
title: "Introduction to Decentralized Identity"
description: Getting Started with Decentralized, Self Sovereign, Digital Identity
excerpt: >
  The essence of Decentralized-ID is in creating open standards for a privacy preserving internet-wide identity layer — not owned by any one particular organization, but interoperable between all.

  It's impossible to have a conversation about decentralized-id without discussing blockchain, self sovereign identity, standardization, frameworks, and government bodies.
layout: single
permalink: /resources/getting-started/
redirect_from:
  - /introduction/ 
  - /getting-started/
  - /resources/
toc: true
categories: ["About"]
tags: ["101","Verifiable Credentials","Decentralized Identifiers"]
last_modified_at: 2023-07-01
---

## Essence of Decentralized Identity

The essence of Decentralized-ID is in creating open standards for a privacy preserving internet-wide identity layer — not owned by any one particular organization, but interoperable between all.

### Background
It's impossible to have a conversation about decentralized-id without discussing blockchain, self sovereign identity, standardization, frameworks, and government bodies.

* Cryptographers, privacy advocates and digital identity enthusiasts [laid the foundation](/history/) by deeply considering the privacy implications of identification practices in the electronic world.
  * [Self Sovereign Identity principles emerged]({% link _posts/meta/2018-12-22-characteristics-principles.md %}) from their work, gathering momentum as the digital age began to settle in.
  * The European Union's GDPR enlarged the global conversation around digital privacy practices, lending much weight to the SSI credo.
* The United Nations Sustainable Development Goals (SDGs) have also fueled efforts towards a global and widely accessible identity solution.
* Satoshi Nakamoto released [Bitcoin](https://bitcoinfo.xyz), proving the concept of digital scarcity in the form of a decentralized peer-to-peer (P2P) currency, inspiring leaders in every industry to integrate it's features to their business models.
* At the same time, [Decentralized web](https://sourcecrypto.pub/decentralized-web/) and P2P technologists have also lent strength to Decentralized Identity efforts.
* Collectively arrived at solutions are trending towards congruence with the spirit of innovation, privacy concerns, and compliance within the evolving global regulatory landscape.
{: .notice--info}

## Getting Started with Decentralized, Self Sovereign, Digital Identity
* [Unwrapping the Decentralised Identity Landscape](https://www.affinidi.com/post/unwrapping-the-decentralised-identity-landscape) 2022-07-08 Affinidi
  > This framework empowers individuals to own his or her data, decide where to store it, and choose to share some or all of it with others. Often, this decentralised identity is used to create verifiable and shareable data for securely accessing products and services.
* [Decentralized identity: The Direct Presentation model](https://techcommunity.microsoft.com/t5/identity-standards-blog/decentralized-identity-the-direct-presentation-model/ba-p/3071981) 2022-02-02 Microsoft
  > The technical name for the model at work here is called the Direct Presentation model. A credential is issued, and then held for a long period of time with intermittent voluntary presentations to many different verifiers.
  ![](https://techcommunity.microsoft.com/t5/image/serverpage/image-id/344648i845AB748FB3E8433/image-dimensions/600x204?v=v2)
* [New to the topic of self-sovereign identity?](https://threadreaderapp.com/thread/1405788127265005571.html) 2021-06-18 SSIAmbassador
  > No problem, there are several beginner #guides, which you can use to get familiar with the new standard for digital #identity.
* [Video] [Understanding the SSI Identity Model with Verifiable Credentials](https://www.youtube.com/watch?v=TRuz39SEX7E) 2021-11-13 Manning
  > Drummond Reed, an expert in Internet identity, security, privacy, and trust frameworks, explains the basic building blocks of SSI and how this new identity model fundamentally works. 
* [Video] [Karyl Fowler (Transmute) and Juan Caballero (DIF) present Intro to SSI at #IIW31](https://www.youtube.com/watch?v=DaM0UtQTLCs) 2020-10 Keryl Fowler, Juan Caballero [Slides](https://drive.google.com/file/d/1_9jCcxgcCrL4Dfjvr4z7XSIwxfadjveR/view?usp=sharingQ)
  > an overview of decentralized identity first as a "philosophy" at the confluence of ideological currents (Juan), and then as a set of specific emerging technologies which unlocks new mental models and business models that are still coming into focus sector by sector (Karyl). There follows a brief overview of educational resources, including some products of DIF's recent educational "content sprint," and a wide-ranging Q&A including podcast recommendations
  > ![](https://i.imgur.com/d0pTD8q.png)
* [What Is Self-Sovereign Identity?](https://trinsic.id/what-is-self-sovereign-identity/) 2020-04-28 Trinsic
  > Self-sovereign identity is the marriage of real identity with the digital world that will ultimately make people’s lives better.² It’s still in its infancy, and there is a long road ahead to truly make digital identity as legitimate and nuanced as a real-world identity.
* [Explaining SSI to C-suite executives, and anyone else for that matter – John Phillips](https://ssimeetup.org/explaining-ssi-c-suite-executives-anyone-else-john-phillips-webinar-48/) 2020-02-18 SSIMeetup
  > John will share the learnings he is gaining from University research, as well as the results of work in supporting capstone projects for higher education students, and how this has led us to a storytelling model to explain SSI.
* [The Need for Good Digital ID is Universal](https://id2020.org/digital-identity) 2019-02-26 ID2020 Foundation
  > The ability to prove who you are is a fundamental and universal human right. Because we live in a digital era, we need a trusted and reliable way to do that both in the physical world and online.
* [The Laws of Identity](http://www.windley.com/archives/2019/01/the_laws_of_identity.shtml) 2019-01 Phil Windley
  > As the Internet grew to include people who weren't formally associated with an institution, every Web site and service created their own administrative identity domains. The result is the fractured plethora of identifiers, policies, and user experiences that constitute digital identity in 2019.
* [The Inevitable Rise of Self-Sovereign Identity](https://sovrin.org/wp-content/uploads/2018/03/The-Inevitable-Rise-of-Self-Sovereign-Identity.pdf) 2018-03 Sovrin Foundation
  > This lack of secure, portable, user-controlled identity has some dire consequences. It means that a person’s identity and personal data only exists within the context of each specific website or application he or she uses. 
* [The Rising Tide of Decentralized Identity](https://medium.com/decentralized-identity/the-rising-tide-of-decentralized-identity-2e163e4ec663) 2017-10-11 Decentralized Identity Foundation
  > - Enabling registration of self-sovereign identifiers that no provider owns or controls.
  > - The ability to lookup and discover identifiers and data across decentralized systems.
  > - Providing a mechanism for users to securely store sensitive identity data, and enabling them to precisely control what is shared with others.
  > ![](https://miro.medium.com/v2/resize:fit:1400/format:webp/1*zzyFrx56I_SzDEUxEglCjw.png)
* [The Case for Decentralized Identity](https://www.windley.com/archives/2017/08/the_case_for_decentralized_identity.shtml) 2017-08 Phil Windley
  > We cannot decentralize many interesting systems without also decentralizing the identity systems upon which they rely. We're finally in a position to create truly decentralized systems for digital identity.
* [The Path to Self-Sovereign Identity](https://github.com/ChristopherA/self-sovereign-identity/blob/master/ThePathToSelf-SovereignIdentity.md) 2017-03-01 Christopher Allen
  > That requires not just the interoperability of a user’s identity across multiple locations, with the user’s consent, but also true user control of that digital identity, creating user autonomy. To accomplish this, a self-sovereign identity must be transportable; it can’t be locked down to one site or locale.
* [A Technology‐Free Definition of Self‐Sovereign Identity](https://raw.githubusercontent.com/jandrieu/rebooting-the-web-of-trust-fall2016/master/topics-and-advance-readings/a-technology-free-definition-of-self-sovereign-identity.pdf) 2016-10 Joe Andrieu RWoT3
  > I want to understand how such a system enables both individuals whose identities are in play (subjects), as well as those who use those “identities” to correlate interactions across contexts (observers). I start with grounding individual sovereignty in the Enlightenment and identity in its core function of correlation, then propose core characteristics of a self‐sovereign identity system.

{% include video id="DaM0UtQTLCs" provider="youtube" %}

## Frequently Asked Questions
* [Knowledgebase] [DIF "Frequently Asked Questions"](https://identity.foundation/faq/) 2022-07-08
  > This is the Decentralized Identity Foundation’s general-purpose knowledgebase, which aims to help people at all levels of familiarity with our problem space quickly level-set and find the most useful links and ideas as they explore the space. 
* [19 FAQs on Verifiable Credentials and Self-Sovereign Identity](https://academy.affinidi.com/faqs-on-verifiable-credentials-and-self-sovereign-identity-3c3a505878bc) 2021-05-31 Affinidi
  > This article has some FAQs on the basics of Verifiable Credentials (VCs) and Self-Sovereign Identity (SSI).
* [Answering Questions about Self-Sovereign Identity](https://www.windley.com/archives/2019/07/answering_questions_about_self-sovereign_identity.shtml) 2019-07 Phil Windley
  > Identity professionals continue to have questions about self-sovereign identity (SSI). In this post, I answer a few questions that Susan Morrow raised about the commercial viability, security, privacy, and desired user experience of SSI.

## Myth
* [For traditional identity models, the biggest misconception is “strong passwords”](https://idramp.com/for-traditional-identity-models-the-biggest-misconception-is-strong-passwords/) 2022-07-20 IDRamp
  > One way to avoid password-related problems is to use decentralized identity management. This method is relatively new, so the best way to gain knowledge about it – contact the experts. For this reason, we are speaking with Mike Vesey, CEO of [IdRamp](https://idramp.com/).
* [Myths about SSI](http://web.archive.org/web/20230209024203/https://jolocom.io/blog/myths-about-ssi/) 2022-05-25 Jolocom
  > The idea that as a user of SSI I have complete sovereignty over my digital identity is often misunderstood. At its core, SSI is about my digital identity being under my own control, so I can decide to whom I show my data, when, and for what.
* [myths and facts. Is Self-Sovereign Identity Dangerous?](http://web.archive.org/web/20230209034007/https://jolocom.io/blog/mythen-und-fakten-ist-self-sovereign-identity-gefahrlich/) 2022-05-05 Jolocom (in german)
  > we examine more closely whether self-sovereign identity can increase or reduce risks for data misuse in certain cases.
* [7 Myths of Self Sovereign Identity](https://medium.com/evernym/7-myths-of-self-sovereign-identity-67aea7416b1) 2018-10-31 Evernym
  > - Self-sovereign means self-attested.
  > - SSI attempts to reduce government’s power over an identity owner.
  > - SSI creates a national or “universal ID” credential.
  > - SSI gives absolute control over identity.
  > - There’s a “main” issuer of credentials.
  > - There’s a built-in method of authenticating.
  > - User-centric identity is the same as SSI.

## Digital Identity 101
* [Understanding Online Identity](https://educatedguesswork.org/posts/understanding-identity/) 2022-06-02 EducatedGuessWork (broad contextualization)
  > As noted above, the ergonomics of having to make an account on every new system are fairly bad: it requires the user to have a large number of passwords, which is more opportunities to use a bad password or to lose your password and have to recover. There are some opportunities for improvement around the margin (e.g., WebAuthn instead of passwords for authentication), better form fill-in so users don't have to type their name over and over, etc, but at the end of the day, there's only so much you can do.
* [Why do you care about identity?](https://wider.team/2022/01/18/phil-cares-about-identity/) 2022-01-18 Phil Wolff 
  > I love that it’s more than a technical discussion. It’s laws. Sociology. Politics and civics. Commerce. Psychology. Ethics. History. Economy. All the humanities.
  > 
  > Identity touches everything. It always will. Computation and communication continue their pervasion, and identity spreads with them.
* [Difference Between Authentication and Authorization](https://www.beyondtrust.com/blog/entry/understanding-authentication-vs-authorization) 2020-10-19 Beyond Trust
  > In concept, one verifies the account (authentication) and the other sanctions (authorization) the account to perform a task. Because these terms are so fundamental, it’s crucial to understand the difference between them, and the implications for each when the concepts are blended
* [Guide to Digital Identity — Part 1](https://medium.com/@dip_ak/guide-to-digital-identity-part-1-4b7c8fe45ee1) 2020-04-08 Deepak Gupta
  > Digital Identity is the new focus for many businesses, regulators and governments in a data-driven and hyper-connected world. The concept can be seen as an integration of two components — belongingness and separation.
* [Member Presentations](https://idpro.org/educational-resources/) Identiverse 2019 [playlist](https://www.youtube.com/playlist?list=PLpKq7xRiIHaTDwAqpIU1UYpKZY03tfTMf)
    * [2019 - Introduction to Identity Part 1](https://www.youtube.com/watch?v=T5w1EXqMqR0&list=PLpKq7xRiIHaTDwAqpIU1UYpKZY03tfTMf) 2019-06-25 Identiverse, IDPro
      > begins with the basics like directories, identity proofing, provisioning, authentication (including multi-factor), authorization, as well as federation technologies like SAML, OAuth, and OpenID Connect. 
    * [Introduction to Identity Part 2](https://www.youtube.com/watch?v=zxKRUXmTLJs)  2019-06-25 Identiverse
	  > we build on those foundational technologies to explain PKI & digital certificates, privileged access management, identity for IoT, identity assurance, privacy issues, identity standards organizations, and even known attack vectors.
    * [Modern Identity for Developers 101](https://www.youtube.com/watch?v=kWpqFWz_9II) 2019-06-25 Identiverse
      > Come to this session to learn the basis of modern identity development and be better equipped to understand and participate to the session in this year’s Identiverse development track.
    * [An Introduction to Mobile Identity](https://www.youtube.com/watch?v=25qiVyZEZOg&list=PLpKq7xRiIHaTDwAqpIU1UYpKZY03tfTMf&index=18) 2019-06-25 Identiverse
* [What is Identity and Access Management and Why is it a Vital IT Security Layer?](https://www.beyondtrust.com/blog/entry/what-is-identity-and-access-management-and-why-is-it-a-vital-it-security-layer) 2018-11-29 Beyond Trust
  > Identity and Access Management (IAM), also called identity management, refers to the IT security discipline, framework, and solutions for managing digital identities. 
* [What is Digital Identity?](https://medium.com/humanizing-the-singularity/what-is-digital-identity-c77983c03306) 2018-06-04 Humanizing the Internet
  > The Sapir–Whorf Hypothesis, also known as the principle of linguistic relativity, posits that language constructs our reality and worldview.
  
![](https://i.imgur.com/9KpJRDr.png)
