---
title: Credentials Community Group - W3C
description: "Drafting and incubating Internet specifications for further standardization; prototyping and testing reference implementations."
excerpt: >
    explore the creation, storage, presentation, verification, and user control of credentials. We focus on a verifiable credential (a set of claims) created by an issuer about a subject—a person, group, or thing—and seek solutions inclusive of approaches such as: self-sovereign identity; presentation of proofs by the bearer; data minimization; and centralized, federated, and decentralized registry and identity systems. 
permalink: /web-standards/sdo/w3c/credentials-community-group/
canonical_url: "https://decentralized-id.com/web-standards/w3c/credentials-community-group/"
categories: ["Standards Development Orgs"]
tags: ["Credentials Community Group","Verifiable Credentials","Decentralized Identifiers","W3C","ECDSA Cryptosuite v2019","ECDSA Cryptosuite v2020","JWS","Tracability","Standards Development Org"]
last_modified_at: 2023-07-03
---

## Main
[GitHub](https://github.com/w3c-ccg/) - [Mailing List Archive](https://lists.w3.org/Archives/Public/public-credentials/) - [Charter](https://www.w3.org/community/credentials/charter) - [Meetings](https://w3c-ccg.github.io/meetings/) - [Announcements](https://w3c-ccg.github.io/announcements/) - [IRC](irc://irc.w3.org/#credentials)

* [Credentials Community Group](https://www.w3.org/community/credentials/) 2014-08-08 W3C
  > to explore the creation, storage, presentation, verification, and user control of credentials. We focus on a verifiable credential (a set of claims) created by an issuer about a subject—a person, group, or thing—and seek solutions inclusive of approaches such as: self-sovereign identity; presentation of proofs by the bearer; data minimization; and centralized, federated, and decentralized registry and identity systems. Our tasks include drafting and incubating Internet specifications for further standardization and prototyping and testing reference implementations.
* [W3C Credentials Community Group](https://w3c-ccg.github.io/) Credentials Community Group
  > Increasing trust on the Web, one spec at a time.
* [CCG 101 - Help us know what is needed!](https://lists.w3.org/Archives/Public/public-credentials/2021May/0150.html) 2021-05-25 Victor Syntez
  > I've invited you to fill out the following form:
  > [CCG 101 - Help us know what’s needed!](https://docs.google.com/forms/d/e/1FAIpQLSe3OakcEg8IfWXYALg10eiii2hiLKq2vXC-yazpPk0QVzIMzQ/viewform?vc=0&amp;c=0&amp;w=1&amp;flr=0&amp;usp=mail_form_link)
* [GDocs] [W3C-CCG Work Item Process](https://docs.google.com/document/d/1vj811aUbs8GwZUNo-LIFBHafsz4rZTSnRtPv7RQaqNc/) 2020-06-19 Credentials Community Group
  > In general, any work that advances the mission is welcome for consideration as a Work Item. A Work Item requires at least one group member willing to commit to being the first editor, another group member (from a different company) willing to be a co-editor, a suggested timeline, and the expected Work Item type, e.g., Community Final Report or Ongoing Repository.

## [Meetings](https://w3c-ccg.github.io/announcements/)

* [Meeting Transcriptions and Audio Recordings (2014-today)](https://w3c-ccg.github.io/meetings/)
  * [Verifiable Credentials for Education task force](https://w3c-ccg.github.io/vc-ed/)
  * [Verifiable Credentials API](https://meet.w3c-ccg.org/vcapi) - how we exchange credentials over REST
  * [Supply Chain Traceability with Verifiable Credentials](https://meet.w3c-ccg.org/traceability)
  * [Confidential Storage](https://forms.gle/HGGiFtgASUqWRqTLA)

## About

* [IRC mailing list bridge](https://lists.w3.org/Archives/Public/public-credentials/2022Apr/0117.html) 2022-04-23 Charles E. Lehner 
  > Notifications of messages to this mailing list (public-credentials) are now sent to our IRC channel (#ccg).
* [CCG updates to cgbot and scribe-tool](https://lists.w3.org/Archives/Public/public-credentials/2021May/0169.html) 2021-05-30 Manu Sporny
  > These are baby steps towards an attempt at auto-transcription and auto-publication of minutes. There are a few things that aren't automated yet (like auto-detecting the meeting name)... ETA on those upgrades is unknown since all these upgrades are on a best effort basis.
* [Reminder: You can present to the CCG](https://lists.w3.org/Archives/Public/public-credentials/2022Mar/0151.html) 2022-03
  > This is a friendly reminder that anyone in the community that is doing something interesting that you think the community should know about whether that work is done here in the CCG or elsewhere, can email the chairs with what you want to share and we can get you on the calendar. It's best if you email all 3 chairs.
* [W3C Credentials Community Group Launch Announcement](https://www.w3.org/community/credentials/launch-pr-draft/) 2014-08-10 Manu Sporny
  > The Credentials Community Group has been launched to create a common way of storing and transmitting low-stakes and high-stakes credentials both on the Web and in the physical world. The founding members of the group include Educational Testing Service (ETS), British Computer Society (BCS), Badge Alliance, Conexxus, Standard Treasury, Accreditrust, Digital Bazaar, NBREDS, COMPANY_X, COMPANY_Y, … and COMPANY_Z. 

## Standards Work
* [2022-2026 Verifiable Data Standards Roadmap [DRAFT]](https://lists.w3.org/Archives/Public/public-credentials/2022Mar/0068.html) 2022-03-12 Manu Sporny
  > ![](https://lists.w3.org/Archives/Public/public-credentials/2022Mar/att-0068/2022_Verifiable_Data_Standards_Roadmap.png)

## Reports
* [RDF Dataset Canonicalization](https://www.w3.org/community/reports/credentials/CG-FINAL-rdf-dataset-canonicalization-20221009/) 2022-10-12
* [JSON Web Signature 2020](https://www.w3.org/community/reports/credentials/CG-FINAL-lds-jws2020-20220721/) 2022-07-26
* [ECDSA Cryptosuite v2019](https://www.w3.org/community/reports/credentials/CG-FINAL-di-ecdsa-2019-20220724/) 2022-07-26
* [EdDSA Cryptosuite v2020](https://www.w3.org/community/reports/credentials/CG-FINAL-di-eddsa-2020-20220724/) 2022-07-26
* [Data Integrity 1.0](https://www.w3.org/community/reports/credentials/CG-FINAL-data-integrity-20220722/) 2022-07-26
* [Decentralized Identifiers (DIDs) v0.13 Data Model and Syntaxes](https://www.w3.org/2019/08/did-20190828/) 2019-09-13
* [Verifiable Claims Use Cases 1.0](https://www.w3.org/2017/05/vc-use-cases/CGFR/2017-05-01/) 2017-05-12
* [Verifiable Claims Data Model and Representations 1.0](https://www.w3.org/2017/05/vc-data-model/CGFR/2017-05-01/) 2017-05-12

