---
title: "~~uPort:~~ Veramo and Serto"
description: A self-sovereign identity and user-centric data platform
layout: single
excerpt: "In your application, you must first configure your uPort object with an identifier and a private key (or signer function). There are several ways to instantiate a credentials object. The most common approach is to save a DID and private key on a server for your application and create a credentials instance from your application's unique private key. Signed JWTs for requests and verifications can then be passed to a client-side application, and presented to a user using a QR code or via another transport."
categories: ["Web 3"]
tags: ["Ethereum","Credentials Community Group","GDPR","DIDComm","Consensys","uPort","Web3","Zug","LibP2P","PWC","Onfido","DIF","Veramo","Serto","GLEIF","uPortlandia","Switzerland","Cheqd","Alastria","LACChain","ENS","Sphereon","Metamask","Spherity"]
redirect_from:
  - id-initiatives/ethereum/uport
  - blockchain/ethereum/uPort
  - id-initiatives/ethereum/uPort/
  - /blockchain/ethereum/uPort/
  - /web-3/ethereum/uPort/
permalink: /web-3/ethereum/uport-veramo-serto/
canonical_url: 'https://decentralized-id.com/web-3/ethereum/uport-veramo-serto/'
last_modified_at: 2023-06-27
---

**uPort project has split into two new projects: Veramo and Serto - both of which carry on the mission of decentralizing the internet.**
{: .notice--success}

## Veramo

**[Veramo](https://veramo.io/) • [GitHub](https://github.com/uport-project) • [Twitter](https://twitter.com/veramolabs) • [Blog](https://medium.com/veramo) • [Docs](https://veramo.io/docs/basics/introduction)**

Performant and modular APIs for Verifiable Data and SSI. Create and manage decentralized identifiers + verifiable credentials without worrying about interop and vendor lock-in.

* [Introduction to Veramo](https://veramo.io/docs/basics/introduction) Veramo Docs
  > Veramo is a JavaScript framework that makes it easy for anyone to use cryptographically verifiable data in their applications. It was designed to make it easy for developers who want to use DIDs, verifiable credentials, and data-centric protocols to bring next-generation features to their users.
* [How we built Cheqd with Veramo](https://medium.com/veramo/how-we-built-cheqd-built-with-veramo-eb59dd793764) 2023-04-14 Veramo
  > Hi, my name is Ankur Banerjee. I’m the CTO and co-founder at cheqd, which is a Decentralized Identity startup. I’ll go into some of the USPS that we are trying to build out, which we are personally quite excited about, and doing that on Veramo SDK as one of the supported SDKs. My journey into digital identity and SSI probably started about five to six years ago. At the time, I was working at a large consultancy called Accenture, and I originally started off working on digital ID for traditional digital identity or traditional enterprises. I worked on a lot of biometrics and ID checking systems for some of the world’s largest banks.
* [Awesome list of awesome Veramo projects](https://github.com/uport-project/veramo/blob/next/AWESOME.md) 2022-10-13 Uport Project
  * [Sphereon SSI SDK](https://github.com/Sphereon-Opensource/ssi-sdk)  
  * [VC Manager plugin](https://github.com/blockchain-lab-um/veramo-vc-manager)
  * [SSI using Metamask snap](https://blockchain-lab-um.github.io/ssi-snap-docs/)
  * [Plugin for did:cheqd](https://github.com/cheqd/did-provider-cheqd)
  * [Spherity VC revocation plugin based on ethereum](https://github.com/spherity/ethr-revocation-registry-veramo-plugin)
  * [RN app with credential signing](https://github.com/symfoni/identity-wallet)
  * [ID Pocket digital identity wallet](https://rktechworks.com/idpocket)
* [ENS names are Decentralized Identifiers (DIDs)](https://medium.com/uport/ens-names-are-decentralized-identifiers-dids-724f0c317e4b) 2021-10-19 uPort
  > DIDs are not a replacement for Ethereum Accounts and ENS. Instead, DIDs can be seen as an abstract representation of those which makes it easier for developers to build applications across different chains and platforms. Many developers in the Decentralized Identity Community are already building a lot of Open Source tooling/products and protocols facilitating trust, privacy, security and data sovereignty, to integrate with the Ethereum ecosystem and vice versa. Some of the Open Source components include decentralized agents (e.g. Veramo), secure communication (i.e. DIDComm Messaging), capabilities-based authorization and delegation frameworks (e.g. ZCaps), login w/ identity wallets (i.e. SIOPv2), user-controlled confidential (e.g. Kepler) or public storage (e.g. Ceramic) and more.
* [DIDComm Messaging through libp2p](https://medium.com/uport/didcomm-messaging-through-libp2p-cffe0f06a062) 2021-11-30 uPort
  > With InterPlanetary File System (IPFS) the Web3 community has established a critical piece of infrastructure that is used by the majority of web3 protocols to different degrees. Libp2p is part of the IPFS stack and is used for the underlying peer-to-peer network for discovery, routing and data exchange. Peers in the network can dial other peers in the network to exchange messages using various transports, like QUIC, TCP, WebSocket, and Bluetooth. Modular design of the libp2p framework enables it to build drivers for other transports. Peers can run on any device, as a cloud service, mobile application or in the browser and talk to each other as long as they are connected through the same libp2p network.
* [Introducing Veramo](https://medium.com/uport/introducing-veramo-5a960bf2a5fe) 2021-06-18 uPort
  > In our last post we briefly presented Veramo and how it evolved from the challenges faced with uPort’s libraries. In this next series of articles we will give Veramo a proper introduction and answer some of the basics: why it exists and what it does, followed by articles describing the architecture in more detail, and how to build applications using Veramo. While our name may have changed, the original vision of allowing individuals and organizations to own their own data and maintain privacy, has not. 
* [Veramo: uPort’s Open Source Evolution](https://medium.com/uport/veramo-uports-open-source-evolution-d85fa463db1f) 2020-05-04 uPort
  > Over time the technical limitations with on-chain identities began to pile up, which led to uPort’s 1.0 architecture and pioneering the use of decentralized identifiers (DIDs) with our open-source libraries. At the time DIDs, together with verifiable credentials (VCs) were proposed W3C standards and are now nearing official status. Dozens of projects are still using several of our popular libraries: uport-connect, uport-credentials, uport-mobile, did-jwt, and did-resolver, to name a few. [...]
  > 
  > Earlier this year, we released the culmination of these efforts, informed by years of open-source work, learning, and iteration, as Veramo.

## Serto

**[Website](https://www.serto.id/) • [Docs](https://docs.serto.id/docs/intro/) • [GitHub](https://github.com/SertoID) • [Twitter](https://twitter.com/serto_id) • [Blog](https://serto.medium.com/)**

Serto enables people and enterprises to utilize the newest innovations in decentralized technology to make data more portable, private, and valuable.

* [Decentralized Identity Linking: Website + Social + NFTs](https://serto.medium.com/decentralized-identity-linking-website-social-nfts-f072162f6901) 2021-10-16 Serto
  > Serto’s Blue Sky Satellite Contest Submission [...]
  > 
  > We used a self-hosted instance of Serto Agent to generate a DID using the WEB:DID method. This DID represents the Serto team.
  > 
  > We signed several verifiable credentials with our DID keys, each written about the location where the messages should appear. We created the W3C standards-compliant verifiable credential schemas using Serto Schemas. 
* [The DAO Plutocracy Problem](https://serto.medium.com/the-dao-plutocracy-problem-a8841546a0f2) 2021-09-10 Serto
  > The challenges of using NFTs for on-chain reputation illuminate superior DAO primitives: trustless off-chain reputation with decentralized identifiers (DIDs) and verifiable credentials (VCs).
* [uPort is now Serto](https://serto.medium.com/uport-is-now-serto-df9c73d545e6) 2021-02-01 Serto
  > Today, Serto continues this critical work with a refined set of tools and a focus on usability and enterprise implementation of DIDs and VCs.
  > 
  > We are joined by alumni of [Alpine](https://medium.com/alpineintel) (a crypto-economics team engineering value with new enterprise transactions) and [Civil](https://joincivil.com/) (a blockchain-based platform for trustworthy journalism), among others, and continue to be part of The Mesh.
* [Connecting and building Trust Between Organizations and People with uPort Serto](https://medium.com/uport/connecting-and-building-trust-between-organizations-and-people-with-uport-serto-32ac6fffdc5e) 2019-11-12 Pelle Braendgaard uPort
  > Examples of real ecosystems we are working with today are:
  > - GLEIF the Global Legal Entity Identifier Foundation, which was founded by the G20 nations to improve transparency in Legal Entity ownership globally. Read about the POC with GLEIF, Banque de France, INSEE, and Societe General here.
  > - Alastria the Spanish National Blockchain Ecosystem
  > - LACChain a new transnational Blockchain Ecosystem sponsored by the Inter-American Development bank
  > - The City of Zug who built the first real Identity Ecosystem on their own
  > - ConsenSys, uPort’s parent company who has made an internal ecosystem using uPort and their https://sobol.io Sobol offering

## uPort
![](https://i.imgur.com/sPAP2g3.png)

* [uPort protocols and libraries](https://developer.uport.me/overview/index#u-port-protocols-and-libraries) 2020-05-02
  > * Transport - [uport-transports](https://developer.uport.me/transports/index) - Backend Devs
  > * uPort Signed Messages - [uport-credentials](https://developer.uport.me/messages/index) - Backend Devs
  > * Signed Messages - [did-jwt](https://tools.ietf.org/html/rfc7519) - Protocol Developers
  > * Identity Abstraction - [did-resolver](https://w3c-ccg.github.io/did-spec/) - Identity Platform Designers
  > * Identity Public Key Lookup - [ethr-did-resolver](https://github.com/ethereum/EIPs/issues/1056) - 
  > * Identity Creation/Management - [ethr-did](https://github.com/uport-project/ethr-did-registry) - Ethereum Identity Wallet Developers
  > * Blockchain API - [web3.js](https://github.com/ethereum/web3.js/) or [ETHJS][https://github.com/ethjs](https://github.com/ethereum/wiki/wiki/JSON-RPC)
  > * Blockchain - [Ethereum](https://ethereum.org/) 
* [GLEIF and uPort Test Verified Data Exchange in Financial Transactions](https://consensys.net/blog/press-release/gleif-uport-test-verified-data-exchange-in-financial-and-commercial-transactions/) 2019-11-07 Consensys
  > Together with uPort, GLEIF is testing how businesses can leverage the Ethereum-backed identity system to increase the efficiency of verifying business identities and persons acting on its behalf within the LEI ecosystem. 
* [uPort donates code to the Decentralized Identity Foundation](https://medium.com/decentralized-identity/uport-donates-code-to-the-decentralized-identity-foundation-349d4740acbd) 2019-11-05 DIF
  - Rather than force people to include support for our older format, we created an entirely new clean library [did-jwt-vc](https://github.com/decentralized-identity/did-jwt-vc) for interacting with Verifiable Credentials from Javascript and TypeScript.
* [PWC and Onfido Join uPort's Portable Identity Effort in UK Finserv](https://consensys.net/blog/press-release/pwc-and-onfido-to-join-uports-portable-identify-efforts-in-uk/) 2019-09-23 Consensys
  > uPort and Onfido have a shared vision of enabling consumers with access and control over their own data. Earlier this year, both companies applied to and were accepted to the UK’s Financial Conduct Authority Regulatory Sandbox (​Cohort 5​) to test how decentralised identity can enable fintech ecosystems in the UK.
* [Welcome to uPortlandia, the Future of Data and Identity Management](https://media.consensys.net/welcome-to-uportlandia-the-future-of-data-and-identity-management-53220ea4e5c) 2019-07-11 Consensys
  > [uPortlandia](https://uportlandia.uport.me/) is uPort’s vision of the future of data and identity management. A future of password-free online experiences. A future where you can prove who you are or verify facts about your life while sharing far less personal information.
* [Goodbye uPort DIDs, Hello Ethr-DIDs](https://medium.com/uport/goodbye-uport-dids-hello-ethr-dids-ea2e80256f54) 2019-01-20 uPort
  > The Ethr-DID library conforms to ERC-1056 and supports the proposed Decentralized Identifiers spec from the W3C Credentials Community Group. These allow for Ethereum addresses to be used as fully self-managed Decentralized Identifiers (DIDs), as a result, you can easily create and manage keys for these identities. This library also allows you to sign standard compliant JSON Web Tokens (JWTs) that can be consumed using the DID-JWT library.
* [uPort: Self-Sovereign Identity Meets Portable Data](https://www.youtube.com/watch?v=hBIragrwqYc) 2018-09-23 MyData Global
  > MyData Global is an international organisation with the aim to create fair digital society.
* [Privacy-Preserving Identity System for Ethereum dApps](https://medium.com/uport/privacy-preserving-identity-system-for-ethereum-dapps-a3352d1a93e8) 2018-04-27 uPort
  > Consider user privacy a requirement when deciding which Ethereum identity system to implement.
* [Literature] [A First Look at Identity Management Schemes on the Blockchain](https://arxiv.org/pdf/1801.03294.pdf) 2018-01-10 IEEE 
  > A final aspect of the uPort scheme is its support for securely mapping identity attributes to a particular uPortID. The uPort registry is a smart contract that stores the global mapping of uPortIDs to identity attributes. Any entity can query the registry, however, only the owner of a specific uPortID can modify its respective attributes. Due to the inefficiency of storing large volumes of data in a smart contract, only the hash of the JSON attribute structure is stored in the registry. The data itself is stored on IPFS: a distributed file system where a file can be retrieved by its cryptographic hash.
* [Ethereum studio ConsenSys launches digital IDs and assets secured on Ubuntu phones](http://www.ibtimes.co.uk/ethereum-studio-consensys-launches-internet-people-digital-ids-assets-secured-unbuntu-phones-1542620) 2016-02-16
  > Nimbus permits users secure interaction with the Ethereum blockchain through biometric protection of cryptographic keys. Through this feature, users will be able to access Ethereum to use decentralised applications (DApps) and develop Ethereum blockchain software.

### Zug ID

* [A position paper on blockchain enabled identity and the road ahead](https://www.bundesblock.de/2018/10/23/position-paper-self-sovereign-identity/) 2018-10-23 Identity Working Group of the German Blockchain Association [PDF](https://www.bundesblock.de/wp-content/uploads/2018/10/ssi-paper.pdf)
  > **City of Zug (UPort and ti&m)** [...] With the SSI implemented in Zug, users can now pay their parking fees, register for elections or perform online sign on for e-government services33. The benefits range for the city of Zug are low infrastructure requirements, decreased security risks, cost effectiveness, GDPR compliance and scalability.
* [Zug ID: Exploring the First Publicly Verified Blockchain Identity](https://medium.com/uport/zug-id-exploring-the-first-publicly-verified-blockchain-identity-38bd0ee3702) 2017-12-07 uPort
  > Thus far, more than 50 citizens in Zug have successfully verified their uPort identity in person with the City, enabling them to access a new suite of e-government services in a trusted and self-reliant manner. 


