---
title: Decentralized Autonomous Organizations (DAO) and Self Sovereign Identity
layout: single
description: "Definitions of “DAO” (short for Decentralized Autonomous Organization) usually start with technology, specifically blockchain."
excerpt: >
  Because DAOs do not have a sovereign above them, and are often explicitly in the business of providing services (like currency and arbitration) that are typically reserved for sovereigns, it is precisely the design of sovereigns (political science), and not the design of corporate governance, that DAOs have more to learn from.
tags: ["Web 3","Ethereum","DAO"]
categories: ["Web 3"]
permalink: /web-3/dao/
canonical_url: "https://decentralized-id.com/web-3/dao/"
last_modified_at: 2023-06-28
---

## DAO Explainer

* [DAOs are not corporations: where decentralization in autonomous organizations matters](https://vitalik.ca/general/2022/09/20/daos.html) 2022-09-20 Vitalik Buterin
  > Because DAOs do not have a sovereign above them, and are often explicitly in the business of providing services (like currency and arbitration) that are typically reserved for sovereigns, it is precisely the design of sovereigns (political science), and not the design of corporate governance, that DAOs have more to learn from.
* [What is a DAO? A non-technical definition](https://reb00ted.org/society/20220703-dao-definition/) 2022-07-03 Reb00ted
  > Definitions of “DAO” (short for Decentralized Autonomous Organization) [usually](https://en.wikipedia.org/wiki/Decentralized_autonomous_organization) [start](https://cointelegraph.com/decentralized-automated-organizations-daos-guide-for-beginners/what-is-decentralized-autonomous-organization-and-how-does-a-dao-work) [with](https://www.investopedia.com/tech/what-dao/) technology, specifically blockchain. But I think that actually misses much of what’s exciting about DAOs, a bit like if you were to explain why your smartphone is great by talking about semiconductor circuits. Let’s try to define DAO without starting with blockchain.
* [Web2's pervasive blind spot: governance](https://reb00ted.org/tech/20220411-web2-blind-spot-goverance/) 2022-04-11 reb00ted
  > Have you noticed that pretty much all senior technologists that dismiss Web3 — usually in highly emotional terms – completely ignore that pretty much all the genuinely interesting innovations in the Web3 world are governance innovations?
* [What can we do with a DAO that cannot be done with other organizational forms?](https://reb00ted.org/tech/20220401-what-can-a-dao-do-that-is-new/) 2022-04-01 Reb00ted
  > I conclude: there is no consensus whatsoever :-) That may be because there such a large range of setups under that term today.
* [Are blockchain-based DAOs really a utopian revolution in the making?](https://www.theguardian.com/commentisfree/2022/mar/12/dont-get-carried-away-in-the-rush-of-dao-idealism-blockchain-cryptofed) 2022-03-12 John Naughton The Guardian
  > DAOs are, I think, one of the best illustrations of the problem with a lot of these Web3 projects: They are trying to find technological solutions that will somehow codify very complex social structures. A lot of them also seem to operate under the assumption that everyone is acting in good faith, and that project members’ interests will generally align—a baffling assumption given the amount of bad actors in the crypto space.
* [A Prehistory of DAOs: Cooperatives, gaming guilds, and the networks to come](https://gnosisguild.mirror.xyz/t4F5rItMw4-mlpLZf5JQhElbDfQ2JRVKAzEpanyxW1Q) 2021-07-21 GnosisGuild
  > The year is 1996. John Perry Barlow is about to declare, “The internet consists of transactions, relationships, and thought itself” ([1](https://www.eff.org/de/cyberspace-independence).
  > 
  > From the vantage point of today’s web, someone might argue that only the first part of Barlow’s statement is correct.
* [Notes] [State of the DAO: Decentralized Governance](https://iiw.idcommons.net/13I/_State_of_the_DAO:_Decentralized_Governance) 2021-05-06 Grace Rachmany
  > - DAO migration from voting to more collaborative tools but look more like an elance platform than a government
  > - Not very bizarre, Oligarchy
  > - Bizarre phenomenon of producers of money not having money
  > - Predictable phenomenon of tech platforms that have no market because we threw so much money at it.
  > - Value-backed protocols and ambitiousness of Holo, in particular the interesting model of having an open source project owning a for-profit company
  > - Moved into the idea of flows rather than objects which
  > - Reputation as a form of communication

## SSI for DAO
* [FaceDAO: Self-sovereign Identity and the Blockchain](https://coinmarketcap.com/alexandria/signals/26487) 2022-06 CoinMarketCap
  > By having SSI in place for users, FaceDAO promises users total security of their data. For FaceDAO, self-sovereign identity on the blockchain implies an identity user’s own. It’s theirs. Only they can hold it on their accounts and only they can decide who gets to see it and what they get to see.
* [Decentralized Identity Use Cases: Self-Sovereign Identities for DAOs](https://medium.com/frctls/fractal-2022-strategy-and-roadmap-update-f29b40547307) 2022-03-07 Fractal
  > Fractal Protocol enables users, individuals to control who has access to their data, for which purposes, and under which conditions. It allows users to reap the just rewards for providing access to the data that fuels the ecosystem.
* [4 Ways Gitcoin Passport Can Help DAOs](https://gitcoin.co/blog/4-ways-gitcoin-passport-can-help-daos/) 2022-08-29 Gitcoin
  > - Fraud Detection
  > - Provenance
  > - Privacy
  > - Verifiable Credentials
* [Using Reputation in DAO Governance](https://medium.com/ontologynetwork/using-reputation-in-dao-governance-7307eb3f3827) 2021-12-29 Ontology
  > a16z, the famous venture capital company, is entering the DAO field through investments into DAO projects, such as the recent investments in social DAO project, FWB.

## Ideas
* [DAOs: Why Sovereign Accountable Commons Might Be Better: Fundamentals for Stronger Communities](https://blog.holochain.org/daos-why-sovereign-accountable-commons-might-be-better/) Holochain
  > We designed Sovereign Accountable Commons (SACs) in order to embed mutual accountability in apps and organizations without needing blockchains to secure the integrity of the space. Because all Holochain apps inherently hold the code underlying SACs, any platform built on Holochain has the ability to follow the principles which we lay out in this article.