---
date: 2019-03-05
title       : "Ethereum and Decentralized Identity"
description : "Ethereum-based Decentralized Identity Specs, Literature, (d)Apps, and GitHub Repositories."
excerpt : "Ethereum-based Decentralized Identity Specs, Literature, (d)Apps, and GitHub Repositories."
header:
  image: #"/images/ethereum-header.webp"
  teaser: #/images/ethereum-thumb.webp
layout: single
author_profile: false
permalink: /blockchain/ethereum/
canonical_url: 'https://decentralized-id.com/blockchain/ethereum/'
redirect_from: 
  - id-initiatives/ethereum
  - id-initiatives/ethereum/
  - ethereum.html
  - ethereum/
categories: ["Web 3"]
tags: ["Ethereum","Jolocom","Web3","Transmute","3box","OASIS","Microsoft","Consensys","ERC725","Nuggets","Sidetree","Web3","Ethereum Enterprise Alliance","uPort","Serto","Veramo","Sign in with ETH","ENS","Web3"]
last_modified_at: 2023-06-26

---

## Competition
* [Ethereum Competitors: Advantages and Disadvantages](https://blog.pantherprotocol.io/ethereum-competitors-advantages-and-disadvantages/) 2022-08-30 Panther Protocol
  > Ethereum competitors that aim for scalability (Solana, Polkadot, Near)
  > * […]Aiming for interoperability (Cosmos, Cardano)
  > * […]Aiming for security (MEV Mitigation) (Solana & Osmosis)
  > * […]Aiming for privacy (Secret Network, Oasis, Panther)

## Decentralized Identity
* [Mastering Decentralized Identity](https://blockworks.co/news/what-is-decentralized-identity) 2023-03-14 Blockworks
  > 1. The current centralized identity system confines the personal and professional development of users to a set of rules and incentives that exploit their attention. 
  > 2. Many major players are invested in a solution, including Disco, SpruceID, Iden3, Polygon ID, Ceramic, the Ethereum Foundation and many more. 
  > 3. The global decentralized identity market value is estimated to reach $6.8 billion by 2027 – according to Markets and Markets
  > 4. Updates in account abstractions and identity wallets have unlocked new possibilities that have yet to be realized.
* [Decentralized identity](https://ethereum.org/en/decentralized-identity/) Ethereum.org
  > traditional identity management systems have long relied on centralized intermediaries who issue, hold, and control your identifiers and attestations. This means you cannot control your identity-related information or decide who has access to personally identifiable information (PII) and how much access these parties have.
  > 
  > To solve these problems, we have decentralized identity systems built on public blockchains like Ethereum. Decentralized identity allows individuals to manage their identity-related information. With decentralized identity solutions, you can create identifiers and claim and hold your attestations without relying on central authorities, like service providers or governments.

## Standards
* [slides] [OAuth 2.0 meets VCs + ETH](https://media.voog.com/0000/0042/0957/files/2020-OSW-SOFIE.pdf) 2020-07-22 Sophie Project
  > * SOFIE enables interoperability between existing IoT platforms
  >   * Utilizes distributed ledger technologies
  >   * 3-year EU Horizon 2020 project, will end in December 2020
  > * SOFIE functionality will be provided through its framework**
  >   * “Privacy and Data Sovereignty,” and “Identity, Authentication, and Authorization” are two key components of the SOFIE framework

### ERC-EIP
* [ERC-5114: Soulbound Badge](https://eips.ethereum.org/EIPS/eip-5114) 2022-05-30 Ethereum
  > A soulbound badge is a token that, when minted, is bound to another Non-Fungible Token (NFT), and cannot be transferred/moved after that.
* [ERC-4361: Sign-In with Ethereum](https://eips.ethereum.org/EIPS/eip-4361) 2021-10-11 Ethereum
  > The goals of this specification are to provide a self-custodied alternative to centralized identity providers, improve interoperability across off-chain services for Ethereum-based authentication, and provide wallet vendors a consistent machine-readable message format to achieve improved user experiences and consent management.
* [ERC-4337: Account Abstraction Using Alt Mempool](https://eips.ethereum.org/EIPS/eip-4337) 2021-09-29 Ethereum
  > An account abstraction proposal which completely avoids consensus-layer protocol changes, instead relying on higher-layer infrastructure.	
* [ERC-1812: Ethereum Verifiable Claims](https://eips.ethereum.org/EIPS/eip-1812) 2019-03-03 Ethereum
  > A new method for Off-Chain Verifiable Claims built on EIP-712. These Claims can be issued by any user with a EIP 712 compatible web3 provider. Claims can be stored off chain and verified on-chain by Solidity Smart Contracts, State Channel Implementations or off-chain libraries.
* [EIP-712: Typed structured data hashing and signing](https://eips.ethereum.org/EIPS/eip-712) 2018-09-26 Ethereum
  > This EIP aims to improve the usability of off-chain message signing for use on-chain. We are seeing growing adoption of off-chain message signing as it saves gas and reduces the number of transactions on the blockchain. Currently signed messages are an opaque hex string displayed to the user with little context about the items that make up the message.
* [ERC-1078: Universal login / signup using ENS subdomains](https://eips.ethereum.org/EIPS/eip-1078) 2018-05-04
  > This presents a method to replace the usual signup/login design pattern with a minimal ethereum native scheme, that doesn’t require passwords, backing up private keys nor typing seed phrases. 
* [EIP-1056: Lightweight Identity](httpshttps://eips.ethereum.org/EIPS/eip-1056) 2018-05-03 Ethereum
  > This ERC describes a standard for creating and updating identities with a limited use of blockchain resources. An identity can have an unlimited number of delegates and attributes associated with it. Identity creation is as simple as creating a regular key pair ethereum account, which means that it's fee (no gas costs) and all ethereum accounts are valid identities. Furthermore this ERC is fully DID compliant.
* [ERC-725: General data key/value store and execution](https://eips.ethereum.org/EIPS/eip-725) 2017-10-02 Ethereum 
  * The following describes two standards that allow for a generic data storage in a smart contract and a generic execution through a smart contract. These can be used separately or in conjunction and can serve as building blocks for smart contract accounts, upgradable metadata, and other means.
* [ERC735](https://github.com/ethereum/EIPs/issues/735) -  The following describes standard functions for adding, removing and holding of claims.
  - These claims can attested from third parties (issuers) or self attested.

### Sidetree \ Element
* [Sidetree Spec V1.0.0](https://identity.foundation/sidetree/spec/) 2023-05-05 DIF
  > Sidetree is a protocol for creating scalable Decentralized Identifier networks that can run atop any existing decentralized anchoring system (e.g. Bitcoin, Ethereum, distributed ledgers, witness-based approaches) and be as open, public, and permissionless as the underlying anchoring systems they utilize. The protocol allows users to create globally unique, user-controlled identifiers and manage their associated PKI metadata, all without the need for centralized authorities or trusted third parties. 
* [Sidetree Core Protocol and DID Method Drivers](https://github.com/transmute-industries/sidetree.js) 2022-09-20 Transmute
  > Sidetree.js is a simple-as-possible TypeScript implementation of the Sidetree version 1.0 protocol. The purpose of the Sidetree protocol is to create a blockchain based public key infrastructure, where rather than having a central authority that can accept or revoke keys, by having the blockchain act as a whitness for regestering public keys, anyone can publish a public key that can be used to establish identity.
* [Introducing Element](https://medium.com/transmute-techtalk/introducing-element-328b4260e757) 2019-05-11 Transmute
  > Transmute is excited to announce Element, an implementation of the Sidetree Protocol on top of Ethereum and IPFS. This work was done in collaboration with Microsoft and Consensys under the Decentralized Identity Foundation (DIF)
  > ...
  > We’re excited to use the serviceEndpoints defined in Element DID documents to track external integrations, in a privacy preserving manner, including identity hubs, credential stores, and more. Furthermore, the scalability that Sidetree brings to DIDs is unprecedented.
* [Element DID Method: Sidetree, Ethereum, IFPS](https://ssimeetup.org/element-did-method-sidetree-ethereum-ipfs-orie-steele-webinar-31/) 2019-07-04 Orie Steele
  > In this talk, Orie will discuss the history of the Element DID Method, how it leverages the same Sidetree Protocol that is used by ION on the Bitcoin Network. He’ll introduce the motivation for Element and ION, and then walk through the core components of developing a working DID System, including topics such as wallets, signing, DID resolution, key revocation, and decentralization.

{% include video id="mk4w2tBTgdE" provider="youtube" %}

## Web3 ID
* [List of 38 Decentralized Identity Tools on Ethereum](https://www.alchemy.com/list-of/decentralized-identity-tools-on-ethereum) Alchemy
* [Web3Modal/web3modal](https://github.com/Web3Modal/web3modal) 2023-06-26
  > Web3Modal is an easy-to-use library to help developers add support for multiple providers in their apps with a simple customizable configuration.
  > By default Web3Modal Library supports injected providers like (Metamask, Dapper, Gnosis Safe, Web3 Browsers, etc) and WalletConnect, You can also easily configure the library to support Portis, Fortmatic, Squarelink, Torus, Authereum, D'CENT Wallet and Arkane.
* [ENS] [How Ethereum Is Shaping Global Identity](https://www.forbes.com/sites/digital-assets/2023/03/10/how-ethereum-is-shaping-global-identity/?sh=341da8aa4560) 2023-03-10 Forbes
  > Imagine a future where you have only one username. One username means only one password. And imagine this one username promises to be more secure, private and trusted than any service offered by Apple﻿﻿, Facebook or Google﻿. This is the promise of the Ethereum﻿ Name System, which is leading the movement to transform everything we know about online identity.
* [Sismo: Attestations on Ethereum Profiles](https://blog.sismo.io/what-is-sismo-part-1-zk-badges-73e7031bacda) 2021-10-14 Sismo
  > Sismo issues badges (non-transferable NFTs) to your public Ethereum profiles (ENS names). They are Zero-Knowledge (ZK) attestations of facts imported from your other accounts (Ethereum accounts as well as twitter or github). You can aggregate your reputation, with confidentiality, to your public profile.
* [EIDM: A Ethereum-Based Cloud User Identity Management Protocol](https://ieeexplore.ieee.org/document/8792212) 2019-06-26 SHANGPING WANG, RU PEI, YALING ZHANG
  > The new protocol is an improved version of CIDM (Consolidated Identity Management) referred to as EIDM (Ethrerum-based Identity Management) protocol. In the improved protocol, JWT (JSON Web Token) in OAuth 2.0 was used to introduce smart contracts into EIDM protocol, and the credit management system was added to the system so that it can provide a credible identity authentication protocol for cloud users and service providers. 

### Sign in with Ethereum - SpruceID
* [Ethereum's Identity Layer - Impact of Ethereum Presentation](https://blog.spruceid.com/presentation-ethereums-identity-layer-impact-of-ethereum/) 2022-09-28 Spruce ID
  > We had the opportunity to present on Ethereum's Identity Layer, covering the evolution of decentralized identity, and how Ethereum presents an incredible opportunity for users to truly own and control their identity and data. Check out that talk in this post.
  > ![](https://i.imgur.com/hheKUW5.png)
* [Self-Sovereign Digital Identity and the Benefits of Ethereum Services in Web3](https://accelerationeconomy.com/metaverse/self-sovereign-digital-identity-and-the-benefits-of-ethereum-services-in-web3/) 2022-06-08 Acceleration Economy
  > An article on CoinDesk pointed out that systems like that of Spruce are superior to current login methods for a number of reasons. Not only does the underlying Ethereum blockchain allow users to directly control their identity and how others use it, but it also boosts the overall transparency of data associated with your account, the persistence of your account, and interoperability between services. So, users don’t need hundreds of different username and password combinations for every website they visit, gluing together fragmented Web2 digital accounts into a coherent Web3 identity, which greatly improves user experience in the Metaverse as well. 
* [Why Sign-In with Ethereum is a Game-Changer Part 2](https://blog.spruceid.com/why-sign-in-with-ethereum-is-a-game-changer-part-2/) 2022-05-27 SpruceID
  > Sign-In with Ethereum opens a path where large corporations can no longer strip a user's ability to access services or spy on their actions. It opens the door for a massive amount of impact in web2 apps and services
* [Sign-In with Ethereum - API Harmonization and TypeScript v2.0 Beta Release](https://blog.spruceid.com/sign-in-with-ethereum-typescript-v2-0-release/) 2022-05-25 SpruceID
  > In our continued updates on Sign-In with Ethereum support, we're pleased to announce that we've harmonized the behavior of our SIWE Core APIs across different languages, added a number of optimizations, and have released a new beta of our TypeScript library with the included changes.
* [CASA Gathering 2022] [Presentation: Extending Sign-In with Ethereum](https://blog.spruceid.com/casa-presentation-extending-sign-in-with-ethereum/) 2022-05-12 SpruceID
  > a [number of breakout sessions](https://github.com/ChainAgnostic/AMS-CASA-gathering/issues) took place, including a session on how Sign-In with Ethereum, CACAOs, and UCANs interoperate, and even one on a unified standard for wallet authentication (sign in with 'x').
* [Sign-In with Ethereum to Your Auth0-Powered Application](https://blog.spruceid.com/sign-in-with-ethereum-on-auth0/) 2022-04-29 Spruce
  > In our pursuit of best serving web2 and web3 organizations, we've partnered with Auth0 to offer a Sign-In with Ethereum option in their marketplace.
* [Sign In With Ethereum (SIWE), Now Available on Auth0](https://auth0.com/blog/sign-in-with-ethereum-siwe-now-available-on-auth0/) 2022-04-19 Auth0
  > Thanks to the hard work of [Spruce](https://www.spruceid.com/), following their [announcement on March 8th](https://blog.spruceid.com/spruce-developer-update-17/), you can now add Sign-in with Ethereum to your Auth0 tenant via their [marketplace integration](https://marketplace.auth0.com/integrations/siwe).
* [Sign-In with Ethereum - Go Library Release](https://blog.spruceid.com/sign-in-with-ethereum-go-library-release/) 2022-03-18 SpruceID
  > Ethereum, we're happy to announce the alpha release of our Go library in order to enable any Go project to leverage SIWE
* [Unlocking Identity and Data Across the Web](https://blog.spruceid.com/how-spruce-is-unlocking-identity-and-data-across-the-web/) 2021-11-09 Web3
  > In recognition of our extensive experience with decentralized identity, Spruce was chosen in September to work with the Ethereum Foundation and ENS to develop Sign-In with Ethereum. This is meant to let users access online services by using their Ethereum accounts as an identifier, rather than an account owned by large corporations like Facebook or Google.

### Web3Auth - Torus Labs
* [Introducing Sign-in with Web3 — Building a Non-Custodial World](https://medium.com/toruslabs/introducing-sign-in-with-web3-building-a-non-custodial-world-50136b3a6225) 2022-06-15 Web3Auth
  > In a much needed multi-chain extension to Sign-in with Ethereum, users will now be able to control their digital identity with their Ethereum/ENS, Solana, and Starknet accounts instead of relying on traditional/custodial profiles.
* [Web3Auth at the Paris Blockchain Week 2022](https://medium.com/toruslabs/web3auth-at-the-paris-blockchain-week-2022-2a26345c9c06) 2022-05-03 Torus
  > A whole lot of ecosystem players at the event were pleasantly surprised to discover Web3Auth’s Key Management Infrastructure
* [Web3Auth at one of the World’s Largest Web3 Events — ETHDenver 2022](https://medium.com/toruslabs/web3auth-at-one-of-the-worlds-largest-web3-events-ethdenver-2022-4a2180621107) 2022-03-03 Torus
  > In the three years since we’ve been active as a Web3 company, this is the second time we had the opportunity to participate in this massive gathering of some of the brightest minds in the Web3 space. What better way to open our presence at ETHDenver than to become official sponsors of the Opening Party?
* [Web3Auth partners with Polygon Studios to bring seamless logins to the Polygon ecosystem](https://medium.com/toruslabs/web3auth-partners-with-polygon-studios-to-bring-seamless-logins-to-the-polygon-ecosystem-fc0db139895d) 2022-01-13 Torus Labs
  > Web3Auth aggregates OAuth (Google, Twitter, Discord) logins, different wallets, and existing key management solutions, and provides dApps/wallets a familiar experience that fits every user. Mobile, web, and blockchain agnostic, Web3Auth fits right into your application or wallet.